@@ -5,8 +5,11 @@ import pytest
 
 import theano
 from tests import unittest_tools as utt
-from theano import config, gof, gradient
+from theano import gradient
+from theano.configdefaults import config
+from theano.gof.graph import Apply
 from theano.gof.null_type import NullType
+from theano.gof.op import Op
 from theano.sandbox.rng_mrg import MRG_RandomStream
 
 
@@ -19,7 +22,7 @@ def grad_sources_inputs(sources, inputs):
     the new interface so the tests don't need to be rewritten.
     """
     if inputs is None:
-        inputs = theano.gof.graph.inputs([source[0] for source in sources])
+        inputs = list(theano.gof.graph.inputs([source[0] for source in sources]))
     return dict(
         zip(
             inputs,
@@ -36,13 +39,13 @@ def grad_sources_inputs(sources, inputs):
 class TestGradSourcesInputs:
     def test_retNone1(self):
         # Test that it is not ok to return None from op.grad()
-        class retNone(gof.op.Op):
+        class retNone(Op):
             __props__ = ()
 
             def make_node(self):
                 inputs = [theano.tensor.vector()]
                 outputs = [theano.tensor.vector()]
-                return gof.Apply(self, inputs, outputs)
+                return Apply(self, inputs, outputs)
 
             def grad(self, inp, grads):
                 (x,) = inp
@@ -55,12 +58,12 @@ class TestGradSourcesInputs:
     def test_wrong_rval_len1(self):
         # Test that it is not ok to return the wrong number of gradient terms
 
-        class retOne(gof.op.Op):
+        class retOne(Op):
             __props__ = ()
 
             def make_node(self, *inputs):
                 outputs = [theano.tensor.vector()]
-                return gof.Apply(self, inputs, outputs)
+                return Apply(self, inputs, outputs)
 
             def grad(self, inputs, grads):
                 return [inputs[0].zeros_like()]
@@ -77,13 +80,13 @@ class TestGradSourcesInputs:
         # Test grad is called correctly for a 1-to-1 op
         gval = theano.tensor.matrix()
 
-        class TestOp(gof.op.Op):
+        class TestOp(Op):
             __props__ = ()
 
             def make_node(self):
                 inputs = [theano.tensor.matrix()]
                 outputs = [theano.tensor.matrix()]
-                return gof.Apply(self, inputs, outputs)
+                return Apply(self, inputs, outputs)
 
             def grad(self, inp, grads):
                 return (gval,)
@@ -96,13 +99,13 @@ class TestGradSourcesInputs:
         # Test grad is called correctly for a 1-to-many op
         gval = theano.tensor.matrix()
 
-        class TestOp(gof.op.Op):
+        class TestOp(Op):
             __props__ = ()
 
             def make_node(self):
                 inputs = [theano.tensor.matrix()]
                 outputs = [theano.tensor.scalar(), theano.tensor.scalar()]
-                return gof.Apply(self, inputs, outputs)
+                return Apply(self, inputs, outputs)
 
             def grad(self, inp, grads):
                 (x,) = inp
@@ -118,13 +121,13 @@ class TestGradSourcesInputs:
         gval0 = theano.tensor.scalar()
         gval1 = theano.tensor.scalar()
 
-        class TestOp(gof.op.Op):
+        class TestOp(Op):
             __props__ = ()
 
             def make_node(self):
                 inputs = [theano.tensor.scalar(), theano.tensor.scalar()]
                 outputs = [theano.tensor.matrix()]
-                return gof.Apply(self, inputs, outputs)
+                return Apply(self, inputs, outputs)
 
             def grad(self, inp, grads):
                 x0, x1 = inp
@@ -141,13 +144,13 @@ class TestGradSourcesInputs:
         gval0 = theano.tensor.matrix()
         gval1 = theano.tensor.matrix()
 
-        class TestOp(gof.op.Op):
+        class TestOp(Op):
             __props__ = ()
 
             def make_node(self):
                 inputs = [theano.tensor.matrix(), theano.tensor.matrix()]
                 outputs = [theano.tensor.matrix(), theano.tensor.matrix()]
-                return gof.Apply(self, inputs, outputs)
+                return Apply(self, inputs, outputs)
 
             def grad(self, inp, grads):
                 return gval0, gval1
@@ -178,11 +181,11 @@ class TestGrad:
     def test_unimplemented_grad_grad(self):
         # tests that unimplemented grads are caught in the grad method
 
-        class DummyOp(gof.Op):
+        class DummyOp(Op):
             __props__ = ()
 
             def make_node(self, x):
-                return gof.Apply(self, [x], [x.type()])
+                return Apply(self, [x], [x.type()])
 
             def grad(self, inputs, output_grads):
                 return [theano.gradient.grad_not_implemented(self, 0, inputs[0])]
@@ -196,11 +199,11 @@ class TestGrad:
     def test_undefined_grad_grad(self):
         # tests that undefined grads are caught in the grad method
 
-        class DummyOp(gof.Op):
+        class DummyOp(Op):
             __props__ = ()
 
             def make_node(self, x):
-                return gof.Apply(self, [x], [x.type()])
+                return Apply(self, [x], [x.type()])
 
             def grad(self, inputs, output_grads):
                 return [theano.gradient.grad_undefined(self, 0, inputs[0])]
@@ -363,7 +366,7 @@ class TestGrad:
 
         # Op1 has two outputs, f and g
         # x is connected to f but not to g
-        class Op1(theano.gof.Op):
+        class Op1(Op):
             __props__ = ()
 
             def make_node(self, x):
@@ -379,7 +382,7 @@ class TestGrad:
 
         # Op2 has two inputs, f and g
         # Its gradient with respect to g is not defined
-        class Op2(theano.gof.Op):
+        class Op2(Op):
             __props__ = ()
 
             def make_node(self, f, g):
