@@ -1,7 +1,7 @@
 """
 Provides `DebugMode`, an evaluation mode for debugging theano internals.
 
-TODO: add support for IfElse Op, LazyLinker, PureOp, etc.
+TODO: add support for IfElse Op, LazyLinker, etc.
 
 """
 
@@ -13,12 +13,13 @@ import sys
 from io import StringIO
 from itertools import chain
 from itertools import product as itertools_product
+from logging import Logger
 from warnings import warn
 
 import numpy as np
 
 import theano
-from theano import config, gof
+from theano import gof
 from theano.compile.function.types import (
     Function,
     FunctionMaker,
@@ -27,31 +28,16 @@ from theano.compile.function.types import (
 )
 from theano.compile.mode import Mode, register_mode
 from theano.compile.ops import OutputGuard, _output_guard
-from theano.gof import graph, ops_with_inner_function, utils
+from theano.configdefaults import config
+from theano.gof import graph, ops_with_inner_function
+from theano.gof.utils import MethodNotDefined
 from theano.link.basic import Container, LocalLinker
 from theano.link.utils import map_storage, raise_with_op
-from theano.utils import get_unbound_function
+from theano.utils import NoDuplicateOptWarningFilter, difference, get_unbound_function
 
 
 __docformat__ = "restructuredtext en"
-_logger = logging.getLogger("theano.compile.debugmode")
-
-
-# Filter to avoid duplicating optimization warnings
-class NoDuplicateOptWarningFilter(logging.Filter):
-    prev_msgs = set()
-
-    def filter(self, record):
-        msg = record.getMessage()
-        if msg.startswith("Optimization Warning: "):
-            if msg in self.prev_msgs:
-                return False
-            else:
-                self.prev_msgs.add(msg)
-                return True
-        return True
-
-
+_logger: Logger = logging.getLogger("theano.compile.debugmode")
 _logger.addFilter(NoDuplicateOptWarningFilter())
 
 
@@ -153,7 +139,7 @@ class BadThunkOutput(DebugModeError):
         return ret
 
 
-class BadOptimization(DebugModeError, theano.gof.toolbox.BadOptimization):
+class BadOptimization(DebugModeError, gof.toolbox.BadOptimization):
     pass
 
 
@@ -536,7 +522,8 @@ def debugprint(
     if used_ids is None:
         used_ids = dict()
 
-    def get_id_str(obj, get_printed=True):
+    def get_id_str(obj, get_printed=True) -> str:
+        id_str: str = ""
         if obj in used_ids:
             id_str = used_ids[obj]
         elif obj == "output":
@@ -1726,7 +1713,7 @@ class _VariableEquivalenceTracker:
 
 # List of default version of make thunk.
 # This is needed to know if the user overrided it.
-default_make_thunk = [get_unbound_function(theano.gof.Op.make_thunk)]
+default_make_thunk = [get_unbound_function(gof.op.COp.make_thunk)]
 
 
 # Debug mode cheats and initializes the linker in a different way in
@@ -1821,21 +1808,19 @@ class _Linker(LocalLinker):
             debug = hasattr(node.op, "debug_perform")
 
             try:
-                if not self.maker.mode.check_c_code or debug:
-                    raise utils.MethodNotDefined()
-                # Ops that do not inherit from gof.op.Op don't have certain
-                # methods defined that the CLinker expects (Scan is an
-                # example, ifelse is another of such classes that inherit
-                # directly from PureOp)
-                if not isinstance(node.op, gof.op.Op):
-                    raise utils.MethodNotDefined()
+                if (
+                    not self.maker.mode.check_c_code
+                    or debug
+                    or not isinstance(node.op, gof.op.COp)
+                ):
+                    raise MethodNotDefined()
 
                 node.op.prepare_node(node, storage_map, compute_map, "c")
                 thunk = node.op.make_c_thunk(
                     node, storage_map, compute_map, no_recycling
                 )
                 thunks_c.append(thunk)
-            except (NotImplementedError, utils.MethodNotDefined):
+            except (NotImplementedError, MethodNotDefined):
                 thunks_c.append(None)
 
             # Pure ops don't really have a perform ( or their perform just
@@ -1843,7 +1828,7 @@ class _Linker(LocalLinker):
             # consider that we don't have a python implementation
             if (
                 (self.maker.mode.check_py_code or thunks_c[-1] is None)
-                and node.op.perform.__code__ != gof.op.PureOp.perform.__code__
+                and node.op.perform.__code__ != gof.op.Op.perform.__code__
             ) or debug:
                 node.op.prepare_node(node, storage_map, compute_map, "py")
                 thunk = node.op.make_py_thunk(
@@ -1853,7 +1838,11 @@ class _Linker(LocalLinker):
             else:
                 thunks_py.append(None)
 
-            if not self.maker.mode.check_c_code and thunks_py[-1] is None:
+            if (
+                not self.maker.mode.check_c_code
+                and thunks_py[-1] is None
+                and isinstance(node.op, gof.op.COp)
+            ):
                 _logger.warning(
                     f"Op {node.op} doesn't have a perform, forcing check of the C code"
                 )
@@ -1882,7 +1871,7 @@ class _Linker(LocalLinker):
         # function's outputs. no_recycling_map will be used in f() below.
         if self.no_recycling is True:
             no_recycling_map = list(storage_map.values())
-            no_recycling_map = utils.difference(no_recycling_map, input_storage)
+            no_recycling_map = difference(no_recycling_map, input_storage)
         else:
             no_recycling_map = [
                 storage_map[r] for r in self.no_recycling if r not in fgraph.inputs
@@ -2000,7 +1989,7 @@ class _Linker(LocalLinker):
                         )
                         try:
                             thunk_py()
-                        except (utils.MethodNotDefined, NotImplementedError):
+                        except (MethodNotDefined, NotImplementedError):
                             # shouldn't have put it into the list in
                             # the first place
                             thunk_py = None
@@ -2426,9 +2415,11 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
         inputs = [self.wrap_in(i) for i in inputs]
         outputs = [self.wrap_out(o) for o in outputs]
 
-        _inputs = gof.graph.inputs(
-            [o.variable for o in outputs]
-            + [i.update for i in inputs if getattr(i, "update", False)]
+        _inputs = list(
+            gof.graph.inputs(
+                [o.variable for o in outputs]
+                + [i.update for i in inputs if getattr(i, "update", False)]
+            )
         )
 
         # Check if some input variables are unused
