@@ -6,6 +6,7 @@ Driver of graph construction, optimization, and linking.
 import copy
 import copyreg
 import logging
+import os
 import pickle
 import time
 import warnings
@@ -15,9 +16,11 @@ import numpy as np
 
 import theano
 import theano.compile.profiling
-from theano import config, gof
+from theano import gof
+from theano.compile.compilelock import lock_ctx
 from theano.compile.io import In, SymbolicInput, SymbolicOutput
 from theano.compile.ops import deep_copy_op, view_op
+from theano.configdefaults import config
 from theano.gof import graph
 from theano.gof.op import ops_with_inner_function
 from theano.gof.toolbox import is_same_graph
@@ -1203,7 +1206,7 @@ def insert_deepcopy(fgraph, wrapped_inputs, wrapped_outputs):
     }
 
     # We can't use fgraph.inputs as this don't include Constant Value.
-    all_graph_inputs = gof.graph.inputs(fgraph.outputs)
+    all_graph_inputs = list(gof.graph.inputs(fgraph.outputs))
     has_destroyers_attr = hasattr(fgraph, "has_destroyers")
 
     for i in range(len(fgraph.outputs)):
@@ -1358,17 +1361,13 @@ class FunctionMaker:
 
     def optimize_graph_with_cache(self, optimizer, inputs, outputs):
         # This function is not finished
-        import os.path
-
-        from theano.gof.compilelock import get_lock, release_lock
-
         graph_db_file = os.path.join(config.compiledir, "optimized_graphs.pkl")
 
         # the inputs, outputs, and size of the graph to be optimized
         inputs_new = [inp.variable for inp in inputs]
         outputs_new = [out.variable for out in outputs]
         size_new = len(self.fgraph.apply_nodes)
-        get_lock()
+
         # Beginning of cache optimizations.
         # Could be refactored in different functions.
 
@@ -1479,29 +1478,30 @@ class FunctionMaker:
                         break
             return found_graph_in_db
 
-        graph_db = load_graph_db()
-        print(f"loaded graph_db from {graph_db_file}, size={len(graph_db)}")
-        found_graph = find_same_graph_in_db(graph_db)
-        if found_graph:
-            self.fgraph = found_graph
-            optimizer_profile = None
-        else:
-            # this is a brand new graph, optimize it, save it to graph_db
-            print("graph not found in graph_db, optimizing the graph")
-            self.fgraph.variables = set(
-                gof.graph.variables(self.fgraph.inputs, self.fgraph.outputs)
-            )
-            # check_integrity parameters was added to ignore
-            # "excess cached variables" errors. Works that way
-            # but once again the error couldbe worth
-            # investigating.
-            before_opt = self.fgraph.clone(check_integrity=False)
-            optimizer_profile = optimizer(self.fgraph)
-            graph_db.update({before_opt: self.fgraph})
-            with open(graph_db_file, "wb") as f:
-                pickle.dump(graph_db, f, -1)
-            print("new graph saved into graph_db")
-        release_lock()
+        with lock_ctx():
+            graph_db = load_graph_db()
+            print(f"loaded graph_db from {graph_db_file}, size={len(graph_db)}")
+            found_graph = find_same_graph_in_db(graph_db)
+            if found_graph:
+                self.fgraph = found_graph
+                optimizer_profile = None
+            else:
+                # this is a brand new graph, optimize it, save it to graph_db
+                print("graph not found in graph_db, optimizing the graph")
+                self.fgraph.variables = set(
+                    gof.graph.variables(self.fgraph.inputs, self.fgraph.outputs)
+                )
+                # check_integrity parameters was added to ignore
+                # "excess cached variables" errors. Works that way
+                # but once again the error couldbe worth
+                # investigating.
+                before_opt = self.fgraph.clone(check_integrity=False)
+                optimizer_profile = optimizer(self.fgraph)
+                graph_db.update({before_opt: self.fgraph})
+                with open(graph_db_file, "wb") as f:
+                    pickle.dump(graph_db, f, -1)
+                print("new graph saved into graph_db")
+
         return optimizer_profile
 
     def __init__(
@@ -1553,9 +1553,11 @@ class FunctionMaker:
         # Wrap them in In or Out instances if needed.
         inputs = [self.wrap_in(i) for i in inputs]
         outputs = [self.wrap_out(o) for o in outputs]
-        _inputs = gof.graph.inputs(
-            [o.variable for o in outputs]
-            + [i.update for i in inputs if getattr(i, "update", False)]
+        _inputs = list(
+            gof.graph.inputs(
+                [o.variable for o in outputs]
+                + [i.update for i in inputs if getattr(i, "update", False)]
+            )
         )
 
         # Check if some input variables are unused
@@ -1697,12 +1699,14 @@ class FunctionMaker:
         # There should be two categories of variables in inputs:
         #  - variables that have to be provided (used_inputs)
         #  - shared variables that will be updated
-        used_inputs = gof.graph.ancestors(
-            (
-                [o.variable for o in outputs]
-                + [i.update for i in inputs if getattr(i, "update", False)]
-            ),
-            blockers=[i.variable for i in inputs],
+        used_inputs = list(
+            gof.graph.ancestors(
+                (
+                    [o.variable for o in outputs]
+                    + [i.update for i in inputs if getattr(i, "update", False)]
+                ),
+                blockers=[i.variable for i in inputs],
+            )
         )
 
         msg = (
