@@ -5,10 +5,9 @@ from theano.gof.destroyhandler import DestroyHandler
 from theano.gof.fg import FunctionGraph, InconsistencyError, MissingInputError
 from theano.gof.graph import Apply, Constant, Variable, view_roots
 from theano.gof.op import (
-    COp,
+    ExternalCOp,
     Op,
     OpenMPOp,
-    PureOp,
     get_test_value,
     ops_with_inner_function,
 )
@@ -44,4 +43,4 @@ from theano.gof.toolbox import (
     Validator,
 )
 from theano.gof.type import CEnumType, EnumList, EnumType, Generic, Type, generic
-from theano.gof.utils import MethodNotDefined, hashtype, object2
+from theano.gof.utils import MetaObject, MethodNotDefined
