@@ -4,7 +4,7 @@ from collections import OrderedDict
 from io import StringIO
 
 import theano
-from theano import config
+from theano.configdefaults import config
 from theano.gof import toolbox, utils
 from theano.gof.graph import Apply, Constant, Variable
 from theano.gof.graph import as_string as graph_as_string
@@ -41,7 +41,7 @@ class MissingInputError(Exception):
         Exception.__init__(self, s)
 
 
-class FunctionGraph(utils.object2):
+class FunctionGraph(utils.MetaObject):
     """
     A `FunctionGraph` represents a subgraph bound by a set of input variables and
     a set of output variables, ie a subgraph that specifies a theano function.
@@ -520,7 +520,7 @@ class FunctionGraph(utils.object2):
             # multiple-output ops
             return
 
-        if theano.config.compute_test_value != "off":
+        if config.compute_test_value != "off":
             try:
                 tval = theano.gof.op.get_test_value(var)
                 new_tval = theano.gof.op.get_test_value(new_var)
@@ -710,7 +710,7 @@ class FunctionGraph(utils.object2):
         Call this for a diagnosis if things go awry.
 
         """
-        nodes = ops_between(self.inputs, self.outputs)
+        nodes = set(ops_between(self.inputs, self.outputs))
         if self.apply_nodes != nodes:
             missing = nodes.difference(self.apply_nodes)
             excess = self.apply_nodes.difference(nodes)
