@@ -1,5 +1,5 @@
 """
-Defines base classes `Op`, `PureOp`, and `CLinkerOp`.
+Defines base classes `Op` and `CLinkerOp`.
 
 The `Op` class is the base interface for all operations
 compatible with `gof`'s :doc:`graph` routines.
@@ -7,25 +7,27 @@ compatible with `gof`'s :doc:`graph` routines.
 """
 import copy
 import inspect
-import logging
 import os
 import re
 import sys
+import typing
 import warnings
 
 import numpy as np
 
 import theano
-from theano import config
+from theano.configdefaults import config
 from theano.gof import graph
 from theano.gof.fg import FunctionGraph
+from theano.gof.graph import Apply, Variable
 from theano.gof.utils import (
+    MetaObject,
     MethodNotDefined,
     TestValueError,
     add_tag_trace,
     get_variable_trace_string,
-    object2,
 )
+from theano.link.c.interface import CLinkerOp
 
 
 __authors__ = "theano-dev"
@@ -35,8 +37,6 @@ __contact__ = "theano-dev <theano-dev@googlegroups.com>"
 
 __docformat__ = "restructuredtext en"
 
-_logger = logging.getLogger("theano.gof.op.Op")
-
 
 def compute_test_value(node):
     """Computes the test value of a node.
@@ -118,448 +118,20 @@ def compute_test_value(node):
         output.tag.test_value = storage_map[output][0]
 
 
-class CLinkerObject:
-    """
-    Standard elements of an Op or Type used with the CLinker.
-
-    """
-
-    def c_headers(self):
-        """
-        Optional: Return a list of header files required by code returned by
-        this class.
-
-        Examples
-        --------
-        return ['<iostream>', '<math.h>', '/full/path/to/header.h']
-
-        These strings will be prefixed with "#include " and inserted at the
-        beginning of the c source code.
-
-        Strings in this list that start neither with '<' nor '"' will be
-        enclosed in double-quotes.
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined("c_headers", type(self), self.__class__.__name__)
-
-    def c_header_dirs(self):
-        """
-        Optional: Return a list of header search paths required by code
-        returned by this class.
-
-        Examples
-        --------
-        return ['/usr/local/include', '/opt/weirdpath/src/include']
-
-        Provides search paths for headers, in addition to those in any relevant
-        environment variables.
-
-        Hint: for unix compilers, these are the things that get '-I' prefixed
-        in the compiler cmdline.
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined("c_header_dirs", type(self), self.__class__.__name__)
-
-    def c_libraries(self):
-        """
-        Optional: Return a list of libraries required by code returned by
-        this class.
-
-        Examples
-        --------
-        return ['gsl', 'gslcblas', 'm', 'fftw3', 'g2c'].
-
-        The compiler will search the directories specified by the environment
-        variable LD_LIBRARY_PATH in addition to any returned by `c_lib_dirs`.
-
-        Hint: for unix compilers, these are the things that get '-l' prefixed
-        in the compiler cmdline.
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined("c_libraries", type(self), self.__class__.__name__)
-
-    def c_lib_dirs(self):
-        """
-        Optional: Return a list of library search paths required by code
-        returned by this class.
-
-        Examples
-        --------
-        return ['/usr/local/lib', '/opt/weirdpath/build/libs'].
-
-        Provides search paths for libraries, in addition to those in any
-        relevant environment variables (e.g. LD_LIBRARY_PATH).
-
-        Hint: for unix compilers, these are the things that get '-L' prefixed
-        in the compiler cmdline.
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined("c_lib_dirs", type(self), self.__class__.__name__)
-
-    def c_support_code(self):
-        """
-        Optional: Return utility code (a string, or a list of strings) for use by a `Variable` or `Op` to be
-        included at global scope prior to the rest of the code for this class.
-
-        QUESTION: How many times will this support code be emitted for a graph
-        with many instances of the same type?
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined("c_support_code", type(self), self.__class__.__name__)
-
-    def c_code_cache_version(self):
-        """
-        Return a tuple of integers indicating the version of this Op.
-
-        An empty tuple indicates an 'unversioned' Op that will not be cached
-        between processes.
-
-        The cache mechanism may erase cached modules that have been superceded
-        by newer versions. See `ModuleCache` for details.
-
-        See Also
-        --------
-        c_code_cache_version_apply()
-
-        """
-        return ()
-
-    def c_compile_args(self):
-        """
-        Optional: Return a list of compile args recommended to compile the
-        code returned by other methods in this class.
-
-        Examples
-        --------
-        return ['-ffast-math']
-
-        Compiler arguments related to headers, libraries and search paths should
-        be provided via the functions `c_headers`, `c_libraries`,
-        `c_header_dirs`, and `c_lib_dirs`.
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined("c_compile_args", type(self), self.__class__.__name__)
-
-    def c_no_compile_args(self):
-        """
-        Optional: return a list of incompatible gcc compiler arguments.
-
-        We will remove those arguments from the command line of gcc. So if
-        another Op adds a compile arg in the graph that is incompatible
-        with this Op, the incompatible arg will not be used.
-        Useful for instance to remove -ffast-math.
-
-        EXAMPLE
-
-        WRITEME
-
-        Raises
-        ------
-        MethodNotDefined
-            The subclass does not override this method.
-
-        """
-        raise MethodNotDefined("c_no_compile_args", type(self), self.__class__.__name__)
-
-    def c_init_code(self):
-        """
-        Optional: return a list of code snippets to be inserted in module
-        initialization.
-
-        Raises
-        ------
-        MethodNotDefined
-            The subclass does not override this method.
-
-        """
-        raise MethodNotDefined("c_init_code", type(self), self.__class__.__name__)
-
-
-class CLinkerOp(CLinkerObject):
-    """
-    Interface definition for `Op` subclasses compiled by `CLinker`.
-
-    A subclass should implement WRITEME.
-
-    WRITEME: structure of automatically generated C code.
-    Put this in doc/code_structure.txt
-
-    """
-
-    def c_code(self, node, name, inputs, outputs, sub):
-        """
-        Required: return the C implementation of an Op.
-
-        Returns C code that does the computation associated to this `Op`,
-        given names for the inputs and outputs.
-
-        Parameters
-        ----------
-        node : Apply instance
-            The node for which we are compiling the current c_code.
-           The same Op may be used in more than one node.
-        name : str
-            A name that is automatically assigned and guaranteed to be
-            unique.
-        inputs : list of strings
-            There is a string for each input of the function, and the
-            string is the name of a C variable pointing to that input.
-            The type of the variable depends on the declared type of
-            the input.  There is a corresponding python variable that
-            can be accessed by prepending "py_" to the name in the
-            list.
-        outputs : list of strings
-            Each string is the name of a C variable where the Op should
-            store its output.  The type depends on the declared type of
-            the output.  There is a corresponding python variable that
-            can be accessed by prepending "py_" to the name in the
-            list.  In some cases the outputs will be preallocated and
-            the value of the variable may be pre-filled.  The value for
-            an unallocated output is type-dependent.
-        sub : dict of strings
-            Extra symbols defined in `CLinker` sub symbols (such as 'fail').
-            WRITEME
-
-        Raises
-        ------
-        MethodNotDefined
-            The subclass does not override this method.
-
-        """
-        raise MethodNotDefined(f"{self.__class__.__name__}.c_code")
-
-    def c_code_cache_version_apply(self, node):
-        """
-        Return a tuple of integers indicating the version of this Op.
-
-        An empty tuple indicates an 'unversioned' Op that will not be
-        cached between processes.
-
-        The cache mechanism may erase cached modules that have been
-        superceded by newer versions.  See `ModuleCache` for details.
-
-        See Also
-        --------
-        c_code_cache_version()
-
-        Notes
-        -----
-            This function overrides `c_code_cache_version` unless it explicitly
-            calls `c_code_cache_version`. The default implementation simply
-            calls `c_code_cache_version` and ignores the `node` argument.
-
-        """
-        return self.c_code_cache_version()
-
-    def c_code_cleanup(self, node, name, inputs, outputs, sub):
-        """
-        Optional: return C code to run after c_code, whether it failed or not.
-
-        This is a convenient place to clean up things allocated by c_code().
-
-        Parameters
-        ----------
-        node : Apply instance
-            WRITEME
-        name : str
-            A name that is automatically assigned and guaranteed to be
-            unique.
-        inputs : list of strings
-            There is a string for each input of the function, and the
-            string is the name of a C variable pointing to that input.
-            The type of the variable depends on the declared type of
-            the input. There is a corresponding python variable that
-            can be accessed by prepending "py_" to the name in the
-            list.
-        outputs : list of strings
-            Each string is the name of a C variable correspoinding to
-            one of the outputs of the Op. The type depends on the
-            declared type of the output. There is a corresponding
-            python variable that can be accessed by prepending "py_" to
-            the name in the list.
-        sub : dict of strings
-            extra symbols defined in `CLinker` sub symbols (such as 'fail').
-            WRITEME
-
-        Raises
-        ------
-        MethodNotDefined
-            The subclass does not override this method.
-
-        """
-        raise MethodNotDefined(f"{self.__class__.__name__}.c_code_cleanup")
-
-    def c_support_code_apply(self, node, name):
-        """
-        Optional: return utility code for use by an `Op` that will be
-        inserted at global scope, that can be specialized for the
-        support of a particular `Apply` node.
-
-        Parameters
-        ----------
-        node: an Apply instance in the graph being compiled
-        name: str
-            A string or number that serves to uniquely identify this node.
-            Symbol names defined by this support code should include the name,
-            so that they can be called from the c_code, and so that they do not
-            cause name collisions.
-
-        Notes
-        -----
-        This function is called in addition to c_support_code and will
-        supplement whatever is returned from there.
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined(
-            "c_support_code_apply", type(self), self.__class__.__name__
-        )
-
-    def c_init_code_apply(self, node, name):
-        """
-        Optional: return a code string specific to the apply
-        to be inserted in the module initialization code.
-
-        Parameters
-        ----------
-        node : an Apply instance in the graph being compiled
-        name : str
-            A string or number that serves to uniquely identify this node.
-            Symbol names defined by this support code should include the name,
-            so that they can be called from the c_code, and so that they do not
-            cause name collisions.
-
-        Notes
-        -----
-        This function is called in addition to c_init_code and will supplement
-        whatever is returned from there.
-
-        Raises
-        ------
-        MethodNotDefined
-            The subclass does not override this method.
-
-        """
-        raise MethodNotDefined("c_init_code_apply", type(self), self.__class__.__name__)
-
-    def c_init_code_struct(self, node, name, sub):
-        """
-        Optional: return a code string specific to the apply
-        to be inserted in the struct initialization code.
-
-        Parameters
-        ----------
-        node : an Apply instance in the graph being compiled
-        name : str
-            A unique name to distinguish variables from those of other nodes.
-        sub
-            A dictionary of values to substitute in the code.
-            Most notably it contains a 'fail' entry that you should place in
-            your code after setting a python exception to indicate an error.
-
-        Raises
-        ------
-        MethodNotDefined
-            The subclass does not override this method.
-
-        """
-        raise MethodNotDefined(
-            "c_init_code_struct", type(self), self.__class__.__name__
-        )
-
-    def c_support_code_struct(self, node, name):
-        """
-        Optional: return utility code for use by an `Op` that will be
-        inserted at struct scope, that can be specialized for the
-        support of a particular `Apply` node.
-
-        Parameters
-        ----------
-        node : an Apply instance in the graph being compiled
-        name : str
-            A unique name to distinguish you variables from those of other
-            nodes.
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined(
-            "c_support_code_struct", type(self), self.__class__.__name__
-        )
-
-    def c_cleanup_code_struct(self, node, name):
-        """
-        Optional: return a code string specific to the apply to be
-        inserted in the struct cleanup code.
-
-        Parameters
-        ----------
-        node : an Apply instance in the graph being compiled
-        name : str
-            A unique name to distinguish variables from those of other nodes.
-
-        Raises
-        ------
-        MethodNotDefined
-            The subclass does not override this method.
-
-        """
-        raise MethodNotDefined(
-            "c_cleanup_code_struct", type(self), self.__class__.__name__
-        )
-
-
-class PureOp:
+class Op(MetaObject):
     """A class that models and constructs operations in a graph.
 
-    A `PureOp` instance has several responsibilities:
+    A `Op` instance has several responsibilities:
 
-    - construct `Apply` nodes via `PureOp.make_node` method,
+    - construct `Apply` nodes via `Op.make_node` method,
 
     - perform the numeric calculation of the modeled operation via
-    the `PureOp.perform` method,
+    the `Op.perform` method,
 
     - and (optionally) build the gradient-calculating sub-graphs via the
-    `PureOp.grad` method.
+    `Op.grad` method.
 
-    To see how `PureOp`, `Type`, `Variable`, and `Apply` fit together see the
+    To see how `Op`, `Type`, `Variable`, and `Apply` fit together see the
     page on :doc:`graph`.
 
     For more details regarding how these methods should behave: see the `Op
@@ -569,7 +141,7 @@ class PureOp:
 
     default_output = None
     """
-    An `int` that specifies which output `PureOp.__call__` should return.  If
+    An `int` that specifies which output `Op.__call__` should return.  If
     `None`, then all outputs are returned.
 
     A subclass should not change this class variable, but instead override it
@@ -577,7 +149,7 @@ class PureOp:
 
     """
 
-    def make_node(self, *inputs):
+    def make_node(self, *inputs) -> Apply:
         """Construct an `Apply` node that represent the application of this operation to the given inputs.
 
         This must be implemented by sub-classes.
@@ -588,12 +160,34 @@ class PureOp:
             The constructed `Apply` node.
 
         """
-        raise MethodNotDefined("make_node", type(self), self.__class__.__name__)
+        if not hasattr(self, "itypes"):
+            raise NotImplementedError(
+                "You can either define itypes and otypes,\
+             or implement make_node"
+            )
 
-    def __call__(self, *inputs, **kwargs):
+        if not hasattr(self, "otypes"):
+            raise NotImplementedError(
+                "You can either define itypes and otypes,\
+             or implement make_node"
+            )
+
+        if len(inputs) != len(self.itypes):
+            raise ValueError(
+                f"We expected {len(self.itypes)} inputs but got {len(inputs)}."
+            )
+        if not all(inp.type == it for inp, it in zip(inputs, self.itypes)):
+            raise TypeError(
+                f"We expected inputs of types '{str(self.itypes)}' but got types '{str([inp.type for inp in inputs])}'"
+            )
+        return theano.Apply(self, inputs, [o() for o in self.otypes])
+
+    def __call__(
+        self, *inputs, **kwargs
+    ) -> typing.Union[Variable, typing.List[Variable],]:
         """Construct an `Apply` node using `self.make_node` and return its outputs.
 
-        This method is just a wrapper around `PureOp.make_node`.
+        This method is just a wrapper around `Op.make_node`.
 
         It is called by code such as:
 
@@ -608,14 +202,14 @@ class PureOp:
         `Variable`, `y`.  The `Apply` node constructed by `self.make_node`
         behind the scenes is available via `y.owner`.
 
-        `PureOp` authors are able to determine which output is returned by this method
-        via the `PureOp.default_output` property., but subclasses are free to override this
+        `Op` authors are able to determine which output is returned by this method
+        via the `Op.default_output` property., but subclasses are free to override this
         function and ignore `default_output`.
 
         Parameters
         ----------
         inputs : tuple of Variable
-            The `PureOp`'s inputs.
+            The `Op`'s inputs.
         kwargs
             Additional keyword arguments to be forwarded to
             `make_node()` *except* for optional argument `return_list` (which
@@ -629,8 +223,8 @@ class PureOp:
         outputs : list of Variable or Variable
             Either a list of output `Variable`s, or a single `Variable`.
             This is determined by the number of outputs produced by the
-            `PureOp`, the value of the keyword `return_list`, and the value of
-            the `PureOp.default_output` property.
+            `Op`, the value of the keyword `return_list`, and the value of
+            the `Op.default_output` property.
 
         """
         return_list = kwargs.pop("return_list", False)
@@ -687,7 +281,7 @@ class PureOp:
         r"""Construct a graph for the L-operator.
 
         This method is primarily used by `tensor.Lop` and dispatches to
-        `PureOp.grad` by default.
+        `Op.grad` by default.
 
         The *L-operator* computes a *row* vector times the Jacobian. The
         mathematical relationship is
@@ -759,9 +353,9 @@ class PureOp:
         with the right number of dimensions and the correct dtype.
         Its shape and stride pattern can be arbitrary. It is not
         guaranteed that such pre-set values were produced by a previous call to
-        this `PureOp.perform`; they could've been allocated by another
-        `PureOp`'s `perform` method.
-        A `PureOp` is free to reuse `output_storage` as it sees fit, or to
+        this `Op.perform`; they could've been allocated by another
+        `Op`'s `perform` method.
+        A `Op` is free to reuse `output_storage` as it sees fit, or to
         discard it and allocate new memory.
 
         Raises
@@ -778,10 +372,10 @@ class PureOp:
             " You can use optimizer=fast_compile instead.",
         )
 
-    def do_constant_folding(self, fgraph, node):
+    def do_constant_folding(self, fgraph: FunctionGraph, node: Apply):
         """Determine whether or not constant folding should be performed for the given node.
 
-        This allows each `PureOp` to determine if it wants to be constant
+        This allows each `Op` to determine if it wants to be constant
         folded when all its inputs are constant. This allows it to choose where
         it puts its memory/speed trade-off. Also, it could make things faster
         as constants can't be used for in-place operations (see
@@ -799,13 +393,6 @@ class PureOp:
         """
         return True
 
-
-class Op(object2, PureOp, CLinkerOp):
-    """
-    Convenience class to bundle `PureOp` and `CLinkerOp`.
-
-    """
-
     # We add a default get_params() implementation which will try to detect params from the op
     # if params_type is set to a ParamsType. If not, we raise a MethodNotDefined exception.
     def get_params(self, node):
@@ -838,59 +425,6 @@ class Op(object2, PureOp, CLinkerOp):
 
         """
 
-    def make_c_thunk(self, node, storage_map, compute_map, no_recycling):
-        """Like make_thunk, but will only try to make a C thunk."""
-        # FIXME: Putting the following import on the module level causes an import cycle.
-        #        The conclusion should be that the antire "make_c_thunk" method should be defined
-        #        in theano.link.c and dispatched onto the Op!
-        import theano.link.c.basic
-
-        node_input_storage = [storage_map[r] for r in node.inputs]
-        node_output_storage = [storage_map[r] for r in node.outputs]
-
-        e = FunctionGraph(node.inputs, node.outputs)
-        e_no_recycling = [
-            new_o
-            for (new_o, old_o) in zip(e.outputs, node.outputs)
-            if old_o in no_recycling
-        ]
-        cl = theano.link.c.basic.CLinker().accept(e, no_recycling=e_no_recycling)
-        # float16 gets special treatment since running
-        # unprepared C code will get bad results.
-        if not getattr(self, "_f16_ok", False):
-
-            def is_f16(t):
-                return getattr(t, "dtype", "") == "float16"
-
-            if any(is_f16(i.type) for i in node.inputs) or any(
-                is_f16(o.type) for o in node.outputs
-            ):
-                # get_dynamic_module is a subset of make_thunk that is reused.
-                # This just try to build the c code
-                # It will raise an error for ops
-                # that don't implement c code. In those cases, we
-                # don't want to print a warning.
-                cl.get_dynamic_module()
-                print(f"Disabling C code for {self} due to unsupported float16")
-                raise NotImplementedError("float16")
-        _logger.debug("Trying CLinker.make_thunk")
-        outputs = cl.make_thunk(
-            input_storage=node_input_storage, output_storage=node_output_storage
-        )
-        thunk, node_input_filters, node_output_filters = outputs
-
-        def rval():
-            thunk()
-            for o in node.outputs:
-                compute_map[o][0] = True
-
-        rval.thunk = thunk
-        rval.cthunk = thunk.cthunk
-        rval.inputs = node_input_storage
-        rval.outputs = node_output_storage
-        rval.lazy = False
-        return rval
-
     def make_py_thunk(self, node, storage_map, compute_map, no_recycling, debug=False):
         """
         Like make_thunk() but only makes python thunks.
@@ -936,7 +470,8 @@ class Op(object2, PureOp, CLinkerOp):
         return rval
 
     def make_thunk(self, node, storage_map, compute_map, no_recycling, impl=None):
-        """
+        """Create a thunk.
+
         This function must return a thunk, that is a zero-arguments
         function that encapsulates the computation to be performed
         by this op on the arguments of the node.
@@ -956,9 +491,9 @@ class Op(object2, PureOp, CLinkerOp):
         no_recycling
             List of variables for which it is forbidden to reuse memory
             allocated by a previous call.
-        impl
-            Currently, None, 'c' or 'py'. If 'c' or 'py' we will only try
-            that version of the code.
+        impl: str
+            Description for the type of node created (e.g. ``"c"``, ``"py"``,
+            etc.)
 
         Notes
         -----
@@ -971,8 +506,78 @@ class Op(object2, PureOp, CLinkerOp):
         self.prepare_node(node, ...) is always called. If we try 'c' and it
         fail and we try again 'py', prepare_node will be called twice.
         """
+        self.prepare_node(
+            node, storage_map=storage_map, compute_map=compute_map, impl="py"
+        )
+        return self.make_py_thunk(node, storage_map, compute_map, no_recycling)
 
-        if (impl is None and theano.config.cxx) or impl == "c":
+
+class COp(Op, CLinkerOp):
+    def make_c_thunk(self, node, storage_map, compute_map, no_recycling):
+        """Like make_thunk, but will only try to make a C thunk."""
+        # FIXME: Putting the following import on the module level causes an import cycle.
+        #        The conclusion should be that the antire "make_c_thunk" method should be defined
+        #        in theano.link.c and dispatched onto the Op!
+        import theano.link.c.basic
+
+        node_input_storage = [storage_map[r] for r in node.inputs]
+        node_output_storage = [storage_map[r] for r in node.outputs]
+
+        e = FunctionGraph(node.inputs, node.outputs)
+        e_no_recycling = [
+            new_o
+            for (new_o, old_o) in zip(e.outputs, node.outputs)
+            if old_o in no_recycling
+        ]
+        cl = theano.link.c.basic.CLinker().accept(e, no_recycling=e_no_recycling)
+        # float16 gets special treatment since running
+        # unprepared C code will get bad results.
+        if not getattr(self, "_f16_ok", False):
+
+            def is_f16(t):
+                return getattr(t, "dtype", "") == "float16"
+
+            if any(is_f16(i.type) for i in node.inputs) or any(
+                is_f16(o.type) for o in node.outputs
+            ):
+                # get_dynamic_module is a subset of make_thunk that is reused.
+                # This just try to build the c code
+                # It will raise an error for ops
+                # that don't implement c code. In those cases, we
+                # don't want to print a warning.
+                cl.get_dynamic_module()
+                print(f"Disabling C code for {self} due to unsupported float16")
+                raise NotImplementedError("float16")
+        outputs = cl.make_thunk(
+            input_storage=node_input_storage, output_storage=node_output_storage
+        )
+        thunk, node_input_filters, node_output_filters = outputs
+
+        def rval():
+            thunk()
+            for o in node.outputs:
+                compute_map[o][0] = True
+
+        rval.thunk = thunk
+        rval.cthunk = thunk.cthunk
+        rval.inputs = node_input_storage
+        rval.outputs = node_output_storage
+        rval.lazy = False
+        return rval
+
+    def make_thunk(self, node, storage_map, compute_map, no_recycling, impl=None):
+        """Create a thunk.
+
+        See `Op.make_thunk`.
+
+        Parameters
+        ----------
+        impl
+            Currently, None, 'c' or 'py'. If 'c' or 'py' we will only try
+            that version of the code.
+
+        """
+        if (impl is None and config.cxx) or impl == "c":
             self.prepare_node(
                 node, storage_map=storage_map, compute_map=compute_map, impl="c"
             )
@@ -982,40 +587,10 @@ class Op(object2, PureOp, CLinkerOp):
                 # We requested the c code, so don't catch the error.
                 if impl == "c":
                     raise
-                _logger.debug("Falling back on perform")
 
-        # condition: either there was no c_code, or it failed or
-        # python code was requested.
-        self.prepare_node(
-            node, storage_map=storage_map, compute_map=compute_map, impl="py"
+        return super().make_thunk(
+            node, storage_map, compute_map, no_recycling, impl=impl
         )
-        return self.make_py_thunk(node, storage_map, compute_map, no_recycling)
-
-    def make_node(self, *inputs):
-        """
-        Create a "apply" nodes for the inputs in that order.
-        """
-        if not hasattr(self, "itypes"):
-            raise NotImplementedError(
-                "You can either define itypes and otypes,\
-             or implement make_node"
-            )
-
-        if not hasattr(self, "otypes"):
-            raise NotImplementedError(
-                "You can either define itypes and otypes,\
-             or implement make_node"
-            )
-
-        if len(inputs) != len(self.itypes):
-            raise ValueError(
-                f"We expected {len(self.itypes)} inputs but got {len(inputs)}."
-            )
-        if not all(inp.type == it for inp, it in zip(inputs, self.itypes)):
-            raise TypeError(
-                f"We expected inputs of types '{str(self.itypes)}' but got types '{str([inp.type for inp in inputs])}'"
-            )
-        return theano.Apply(self, inputs, [o() for o in self.otypes])
 
 
 def get_test_value(v):
@@ -1121,7 +696,7 @@ For instance, Scan will be registered here.
 """
 
 
-class OpenMPOp(Op):
+class OpenMPOp(COp):
     """
     All op using OpenMP code should inherit from this Op.
 
@@ -1144,7 +719,7 @@ class OpenMPOp(Op):
 
     def __init__(self, openmp=None):
         if openmp is None:
-            openmp = theano.config.openmp
+            openmp = config.openmp
         self.openmp = openmp
 
     def __setstate__(self, d):
@@ -1215,7 +790,7 @@ int main( int argc, const char* argv[] )
                     )
             if OpenMPOp.gxx_support_openmp is False:
                 self.openmp = False
-                theano.config.openmp = False
+                config.openmp = False
 
     def prepare_node(self, node, storage_map, compute_map, impl):
         if impl == "c":
@@ -1247,7 +822,7 @@ def apply_meth(tag):
     return f
 
 
-class COp(Op):
+class ExternalCOp(COp):
     """
     Class to allow an op to have an external C implementation.
 
@@ -1417,7 +992,7 @@ class COp(Op):
                 try:
                     # NB (reminder): These macros are currently used only in ParamsType example test
                     # (`theano/gof/tests/test_quadratic_function.c`), to demonstrate how we can
-                    # access params dtypes when dtypes may change (e.g. if based on theano.config.floatX).
+                    # access params dtypes when dtypes may change (e.g. if based on config.floatX).
                     # But in practice, params types generally have fixed types per op.
                     params.append(
                         (
