@@ -11,265 +11,16 @@ import platform
 import re
 
 import theano
-from theano import config
+from theano.configdefaults import config
 from theano.gof import graph, utils
-
-########
-# Type #
-########
-from theano.gof.op import CLinkerObject, Op
-from theano.gof.utils import MethodNotDefined, object2
+from theano.gof.op import COp
+from theano.gof.utils import MetaObject, MethodNotDefined
+from theano.link.c.interface import CLinkerType
 
 
 __docformat__ = "restructuredtext en"
 
 
-class CLinkerType(CLinkerObject):
-    """
-    Interface specification for Types that can be arguments to a `CLinkerOp`.
-
-    A CLinkerType instance is mainly responsible  for providing the C code that
-    interfaces python objects with a C `CLinkerOp` implementation.
-
-    See WRITEME for a general overview of code generation by `CLinker`.
-
-    """
-
-    def c_element_type(self):
-        """
-        Optional: Return the name of the primitive C type of items into variables
-        handled by this type.
-
-        e.g:
-
-         - For ``TensorType(dtype='int64', ...)``: should return ``"npy_int64"``.
-         - For ``GpuArrayType(dtype='int32', ...)``: should return ``"ga_int"``.
-
-        """
-        raise MethodNotDefined("c_element_type", type(self), self.__class__.__name__)
-
-    def c_is_simple(self):
-        """
-        Optional: Return True for small or builtin C types.
-
-        A hint to tell the compiler that this type is a builtin C type or a
-        small struct and that its memory footprint is negligible. Simple
-        objects may be passed on the stack.
-
-        """
-        return False
-
-    def c_literal(self, data):
-        """
-        Optional: WRITEME
-
-        Parameters
-        ----------
-        data : WRITEME
-            WRITEME
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined("c_literal", type(self), self.__class__.__name__)
-
-    def c_declare(self, name, sub, check_input=True):
-        """
-        Required: Return c code to declare variables that will be
-        instantiated by `c_extract`.
-
-        Parameters
-        ----------
-        name: str
-            The name of the ``PyObject *`` pointer that will
-            the value for this Type
-        sub: dict string -> string
-            a dictionary of special codes.  Most importantly
-            sub['fail']. See CLinker for more info on `sub` and ``fail``.
-
-        Notes
-        -----
-        It is important to include the `name` inside of variables which
-        are declared here, so that name collisions do not occur in the
-        source file that is generated.
-
-        The variable called ``name`` is not necessarily defined yet
-        where this code is inserted. This code might be inserted to
-        create class variables for example, whereas the variable ``name``
-        might only exist inside certain functions in that class.
-
-        TODO: Why should variable declaration fail?  Is it even allowed to?
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        Examples
-        --------
-        .. code-block: python
-
-            return "PyObject ** addr_of_%(name)s;"
-
-        """
-        raise MethodNotDefined()
-
-    def c_init(self, name, sub):
-        """
-        Required: Return c code to initialize the variables that were declared
-        by self.c_declare().
-
-        Notes
-        -----
-        The variable called ``name`` is not necessarily defined yet
-        where this code is inserted. This code might be inserted in a
-        class constructor for example, whereas the variable ``name``
-        might only exist inside certain functions in that class.
-
-        TODO: Why should variable initialization fail?  Is it even allowed to?
-
-        Examples
-        --------
-        .. code-block: python
-
-            return "addr_of_%(name)s = NULL;"
-
-        """
-        raise MethodNotDefined("c_init", type(self), self.__class__.__name__)
-
-    def c_extract(self, name, sub, check_input=True):
-        """
-        Required: Return c code to extract a PyObject * instance.
-
-        The code returned from this function must be templated using
-        ``%(name)s``, representing the name that the caller wants to
-        call this `Variable`. The Python object self.data is in a
-        variable called "py_%(name)s" and this code must set the
-        variables declared by c_declare to something representative
-        of py_%(name)s. If the data is improper, set an appropriate
-        exception and insert "%(fail)s".
-
-        TODO: Point out that template filling (via sub) is now performed
-              by this function. --jpt
-
-        Parameters
-        ----------
-        name : str
-            The name of the ``PyObject *`` pointer that will
-            store the value for this Type.
-        sub : dict string -> string
-            A dictionary of special codes. Most importantly
-            sub['fail']. See CLinker for more info on `sub` and ``fail``.
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        Examples
-        --------
-        .. code-block: python
-
-            return "if (py_%(name)s == Py_None)" + \\\
-                        addr_of_%(name)s = &py_%(name)s;" + \\\
-                   "else" + \\\
-                   { PyErr_SetString(PyExc_ValueError, \\\
-                        'was expecting None'); %(fail)s;}"
-
-        """
-        raise MethodNotDefined("c_extract", type(self), self.__class__.__name__)
-
-    def c_extract_out(self, name, sub, check_input=True):
-        """
-        Optional: C code to extract a PyObject * instance.
-
-        Unlike c_extract, c_extract_out has to accept Py_None,
-        meaning that the variable should be left uninitialized.
-
-        """
-        return """
-        if (py_%(name)s == Py_None)
-        {
-            %(c_init_code)s
-        }
-        else
-        {
-            %(c_extract_code)s
-        }
-        """ % dict(
-            name=name,
-            c_init_code=self.c_init(name, sub),
-            c_extract_code=self.c_extract(name, sub, check_input),
-        )
-
-    def c_cleanup(self, name, sub):
-        """
-        Return C code to clean up after `c_extract`.
-
-        This returns C code that should deallocate whatever `c_extract`
-        allocated or decrease the reference counts. Do not decrease
-        py_%(name)s's reference count.
-
-        WRITEME
-
-        Parameters
-        ----------
-        name : WRITEME
-            WRITEME
-        sub : WRITEME
-            WRITEME
-
-        Raises
-        ------
-         MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined()
-
-    def c_sync(self, name, sub):
-        """
-        Required: Return C code to pack C types back into a PyObject.
-
-        The code returned from this function must be templated using
-        "%(name)s", representing the name that the caller wants to
-        call this Variable. The returned code may set "py_%(name)s"
-        to a PyObject* and that PyObject* will be accessible from
-        Python via variable.data. Do not forget to adjust reference
-        counts if "py_%(name)s" is changed from its original value.
-
-        Parameters
-        ----------
-        name : WRITEME
-            WRITEME
-        sub : WRITEME
-            WRITEME
-
-        Raises
-        ------
-        MethodNotDefined
-            Subclass does not implement this method.
-
-        """
-        raise MethodNotDefined("c_sync", type(self), self.__class__.__name__)
-
-    def c_code_cache_version(self):
-        """
-        Return a tuple of integers indicating the version of this Type.
-
-        An empty tuple indicates an 'unversioned' Type that will not
-        be cached between processes.
-
-        The cache mechanism may erase cached modules that have been
-        superceded by newer versions. See `ModuleCache` for details.
-
-        """
-        return ()
-
-
 class PureType:
     """
     Interface specification for variable type instances.
@@ -470,7 +221,7 @@ _nothing = """
        """
 
 
-class Type(object2, PureType, CLinkerType):
+class Type(MetaObject, PureType, CLinkerType):
     """
     Convenience wrapper combining `PureType` and `CLinkerType`.
 
@@ -619,7 +370,7 @@ if platform.python_implementation() != "PyPy":
     ).value
 
 
-class _make_cdata(Op):
+class _make_cdata(COp):
     __props__ = ("rtype",)
 
     def __init__(self, rtype):
