@@ -6,12 +6,16 @@ from collections import deque
 import numpy as np
 
 import theano
-from theano import Apply, Op, Type, Variable, config, tensor
-from theano.gof import COp, ParamsType
+from theano import tensor
+from theano.configdefaults import config
+from theano.gof.graph import Apply, Variable
+from theano.gof.op import COp, ExternalCOp, Op
 from theano.gof.opt import copy_stack_trace
+from theano.gof.params_type import ParamsType
+from theano.gof.type import Type
 from theano.gof.utils import MethodNotDefined
 from theano.gradient import grad_undefined
-from theano.link.c.basic import HideC
+from theano.link.c.interface import HideC
 from theano.scalar import bool as bool_t
 from theano.scalar import int32 as int32_t
 from theano.tensor.basic import Alloc, AllocEmpty, Join, Split, alloc_validate_shape
@@ -493,7 +497,7 @@ def forward_string_meth(name):
     def f(*args):
         res = getattr(GpuKernelBase, name)(*args)
         try:
-            res = res + "\n" + getattr(COp, name)(*args)
+            res = res + "\n" + getattr(ExternalCOp, name)(*args)
         except MethodNotDefined:
             pass
         return res
@@ -513,15 +517,15 @@ def get_dtype(s):
         return np.dtype(s)
 
 
-class CGpuKernelBase(COp, GpuKernelBase):
+class CGpuKernelBase(ExternalCOp, GpuKernelBase):
     """
-    Class to combine GpuKernelBase and COp.
+    Class to combine GpuKernelBase and ExternalCOp.
 
     It adds a new section type 'kernels' where you can define kernels
     with the '#kernel' tag
     """
 
-    SECTIONS = copy.copy(COp.SECTIONS)
+    SECTIONS = copy.copy(ExternalCOp.SECTIONS)
     SECTIONS.add("kernels")
 
     kernel_re = re.compile(r"^#kernel ([a-zA-Z_].*?)$", re.MULTILINE)
@@ -587,7 +591,7 @@ class CGpuKernelBase(COp, GpuKernelBase):
             return GpuKernelBase.gpu_kernels(self, node, name)
 
 
-class HostFromGpu(Op):
+class HostFromGpu(COp):
     """
     Transfer data to CPU.
 
@@ -680,7 +684,7 @@ class HostFromGpu(Op):
 host_from_gpu = HostFromGpu()
 
 
-class GpuFromHost(Op):
+class GpuFromHost(COp):
     """
     Transfer data to GPU.
 
@@ -783,7 +787,7 @@ class GpuFromHost(Op):
         return (10,)
 
 
-class GpuToGpu(Op):
+class GpuToGpu(COp):
     """
     Transfer data between GPUs.
 
