@@ -11,10 +11,12 @@ from io import StringIO
 
 import numpy as np
 
-from theano import config
-from theano.gof import graph, utils
+from theano.compile.compilelock import lock_ctx
+from theano.configdefaults import config
 from theano.gof.callcache import CallCache
-from theano.gof.compilelock import get_lock, release_lock
+from theano.gof.graph import Constant, NoParams, io_toposort
+from theano.gof.graph import variables as get_variables
+from theano.gof.utils import MethodNotDefined
 from theano.link.basic import Container, Linker, LocalLinker, PerformLinker
 from theano.link.c.cmodule import (
     METH_VARARGS,
@@ -25,6 +27,7 @@ from theano.link.c.cmodule import (
 )
 from theano.link.c.cmodule import get_module_cache as _get_module_cache
 from theano.link.utils import gc_helper, map_storage, raise_with_op, streamline
+from theano.utils import difference, uniq
 
 
 _logger = logging.getLogger("theano.link.c.basic")
@@ -634,14 +637,14 @@ class CLinker(Linker):
         # We need to include the unused inputs in our variables,
         # otherwise we can't pass them to the module.
         self.variables = [var for var in self.inputs if not len(fgraph.clients[var])]
-        self.variables += graph.variables(self.inputs, self.outputs)
+        self.variables += list(get_variables(self.inputs, self.outputs))
 
         # This adds a hidden input which is the params for each node
         # that needs it
         self.node_params = dict()
         for node in self.node_order:
             params = node.run_params()
-            if params is not graph.NoParams:
+            if params is not NoParams:
                 # try to avoid creating more than one variable for the
                 # same params.
                 if params in self.node_params:
@@ -649,7 +652,7 @@ class CLinker(Linker):
                     assert var.type == node.params_type
                     fgraph.clients[var].append((node, "params"))
                 else:
-                    var = graph.Constant(node.params_type, params)
+                    var = Constant(node.params_type, params)
                     fgraph.clients[var] = [(node, "params")]
                     self.node_params[params] = var
                     self.variables.append(var)
@@ -659,18 +662,18 @@ class CLinker(Linker):
         self.orphans = list(
             r
             for r in self.variables
-            if isinstance(r, graph.Constant) and r not in self.inputs
+            if isinstance(r, Constant) and r not in self.inputs
         )
         # C type constants (theano.scalar.Scalar). They don't request an object
         self.consts = []
         # Move c type from orphans (theano.scalar.Scalar) to self.consts
         for variable in self.orphans:
-            if isinstance(variable, graph.Constant):
+            if isinstance(variable, Constant):
                 try:
                     variable.type.c_literal(variable.data)
                     self.consts.append(variable)
                     self.orphans.remove(variable)
-                except (utils.MethodNotDefined, NotImplementedError):
+                except (MethodNotDefined, NotImplementedError):
                     pass
 
         self.temps = list(
@@ -741,7 +744,7 @@ class CLinker(Linker):
                     [get_c_declare, get_c_extract, get_c_cleanup],
                 ]
             elif variable in self.orphans:
-                if not isinstance(variable, graph.Constant):
+                if not isinstance(variable, Constant):
                     raise TypeError(
                         "All orphans to CLinker must be Constant" " instances.",
                         variable,
@@ -817,7 +820,7 @@ class CLinker(Linker):
             sub = dict(failure_var=failure_var)
 
             params = node.run_params()
-            if params is not graph.NoParams:
+            if params is not NoParams:
                 params_var = symbol[self.node_params[params]]
 
             # The placeholder will be replaced by a hash of the entire
@@ -832,13 +835,13 @@ class CLinker(Linker):
             # Make the CodeBlock for c_code
             sub["id"] = id
             sub["fail"] = failure_code(sub)
-            if params is not graph.NoParams:
+            if params is not NoParams:
                 sub["params"] = params_var
 
             sub_struct = dict()
             sub_struct["id"] = id + 1
             sub_struct["fail"] = failure_code_init(sub)
-            if params is not graph.NoParams:
+            if params is not NoParams:
                 # Since params inputs are always constants they are
                 # guaranteed to be available in the struct init code.
                 sub_struct["params"] = params_var
@@ -851,7 +854,7 @@ class CLinker(Linker):
             # type-specific support code
             try:
                 c_support_code_apply.append(op.c_support_code_apply(node, name))
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
             else:
                 # The following will be executed if the "try" block succeeds
@@ -861,7 +864,7 @@ class CLinker(Linker):
 
             try:
                 c_init_code_apply.append(op.c_init_code_apply(node, name))
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
             else:
                 assert isinstance(c_init_code_apply[-1], str), (
@@ -873,7 +876,7 @@ class CLinker(Linker):
                 assert isinstance(struct_init, str), (
                     str(node.op) + " didn't return a string for c_init_code_struct"
                 )
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
 
             try:
@@ -881,7 +884,7 @@ class CLinker(Linker):
                 assert isinstance(struct_support, str), (
                     str(node.op) + " didn't return a string for c_support_code_struct"
                 )
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
 
             try:
@@ -889,13 +892,13 @@ class CLinker(Linker):
                 assert isinstance(struct_cleanup, str), (
                     str(node.op) + " didn't return a string for c_cleanup_code_struct"
                 )
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
 
             # emit c_code
             try:
                 behavior = op.c_code(node, name, isyms, osyms, sub)
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 raise NotImplementedError(f"{op} cannot produce C code")
             assert isinstance(
                 behavior, str
@@ -907,7 +910,7 @@ class CLinker(Linker):
 
             try:
                 cleanup = op.c_code_cleanup(node, name, isyms, osyms, sub)
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 cleanup = ""
 
             _logger.info(f"compiling un-versioned Apply {node}")
@@ -930,7 +933,7 @@ class CLinker(Linker):
         args = []
         args += [
             f"storage_{symbol[variable]}"
-            for variable in utils.uniq(self.inputs + self.outputs + self.orphans)
+            for variable in uniq(self.inputs + self.outputs + self.orphans)
         ]
 
         # <<<<HASH_PLACEHOLDER>>>> will be replaced by a hash of the whole
@@ -991,7 +994,7 @@ class CLinker(Linker):
                     ret.extend(support_code)
                 else:
                     ret.append(support_code)
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
         return ret
 
@@ -1029,10 +1032,10 @@ class CLinker(Linker):
                     ret += x.c_compile_args(c_compiler)
                 except TypeError:
                     ret += x.c_compile_args()
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
 
-        ret = utils.uniq(ret)  # to remove duplicate
+        ret = uniq(ret)  # to remove duplicate
         # The args set by the compiler include the user flags. We do not want
         # to reorder them
         ret += c_compiler.compile_args()
@@ -1047,7 +1050,7 @@ class CLinker(Linker):
                         ret.remove(i)
                     except ValueError:
                         pass  # in case the value is not there
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
         return ret
 
@@ -1067,9 +1070,9 @@ class CLinker(Linker):
                     ret += x.c_headers(c_compiler)
                 except TypeError:
                     ret += x.c_headers()
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
-        return utils.uniq(ret)
+        return uniq(ret)
 
     def init_code(self):
         """
@@ -1083,9 +1086,9 @@ class CLinker(Linker):
         for x in [y.type for y in self.variables] + [y.op for y in self.node_order]:
             try:
                 ret += x.c_init_code()
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
-        return utils.uniq(ret)
+        return uniq(ret)
 
     def c_compiler(self):
         c_compiler = None
@@ -1124,10 +1127,10 @@ class CLinker(Linker):
                     ret += x.c_header_dirs(c_compiler)
                 except TypeError:
                     ret += x.c_header_dirs()
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
         # filter out empty strings/None
-        return [r for r in utils.uniq(ret) if r]
+        return [r for r in uniq(ret) if r]
 
     def libraries(self):
         """
@@ -1145,9 +1148,9 @@ class CLinker(Linker):
                     ret += x.c_libraries(c_compiler)
                 except TypeError:
                     ret += x.c_libraries()
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
-        return utils.uniq(ret)
+        return uniq(ret)
 
     def lib_dirs(self):
         """
@@ -1165,13 +1168,16 @@ class CLinker(Linker):
                     ret += x.c_lib_dirs(c_compiler)
                 except TypeError:
                     ret += x.c_lib_dirs()
-            except utils.MethodNotDefined:
+            except MethodNotDefined:
                 pass
         # filter out empty strings/None
-        return [r for r in utils.uniq(ret) if r]
+        return [r for r in uniq(ret) if r]
 
     def __compile__(
-        self, input_storage=None, output_storage=None, storage_map=None, keep_lock=False
+        self,
+        input_storage=None,
+        output_storage=None,
+        storage_map=None,
     ):
         """
         Compiles this linker's fgraph.
@@ -1213,7 +1219,6 @@ class CLinker(Linker):
             input_storage,
             output_storage,
             storage_map,
-            keep_lock=keep_lock,
         )
         return (
             thunk,
@@ -1245,9 +1250,7 @@ class CLinker(Linker):
             id += 2
         return init_tasks, tasks
 
-    def make_thunk(
-        self, input_storage=None, output_storage=None, storage_map=None, keep_lock=False
-    ):
+    def make_thunk(self, input_storage=None, output_storage=None, storage_map=None):
         """
         Compiles this linker's fgraph and returns a function to perform the
         computations, as well as lists of storage cells for both the inputs
@@ -1266,9 +1269,6 @@ class CLinker(Linker):
         storage_map: dict that map variables to storages.
             This is used when you need to customize the storage of
             this thunk
-        keep_lock:
-            If True, we won't release the lock on the compiledir
-            at the end of this function call.
         Returns: thunk, input_storage, output_storage
 
         The return values can be used as follows:
@@ -1280,7 +1280,7 @@ class CLinker(Linker):
         """
         init_tasks, tasks = self.get_init_tasks()
         cthunk, module, in_storage, out_storage, error_storage = self.__compile__(
-            input_storage, output_storage, storage_map, keep_lock=keep_lock
+            input_storage, output_storage, storage_map
         )
 
         res = _CThunk(cthunk, init_tasks, tasks, error_storage, module)
@@ -1398,7 +1398,7 @@ class CLinker(Linker):
                 # doesn't need to include information about inplace operations
                 # because that information will be included explicitly in
                 # cmodule_key_().
-                return graph.io_toposort(self.inputs, self.outputs)
+                return io_toposort(self.inputs, self.outputs)
 
         fgraph = FakeFunctionGraph(inputs, outputs)
         return self.cmodule_key_(
@@ -1494,7 +1494,7 @@ class CLinker(Linker):
 
             # It is important that a variable (i)
             # yield a 'position' that reflects its role in code_gen()
-            if isinstance(i, graph.Constant):  # orphans
+            if isinstance(i, Constant):  # orphans
                 if id(i) not in constant_ids:
                     isig = (i.signature(), topological_pos, i_idx)
                     # If the Theano constant provides a strong hash
@@ -1614,23 +1614,21 @@ class CLinker(Linker):
         preargs = self.compile_args()
         # We want to compute the code without the lock
         src_code = mod.code()
-        get_lock()
-        try:
-            _logger.debug(f"LOCATION {location}")
-            module = c_compiler.compile_str(
-                module_name=mod.code_hash,
-                src_code=src_code,
-                location=location,
-                include_dirs=self.header_dirs(),
-                lib_dirs=self.lib_dirs(),
-                libs=libs,
-                preargs=preargs,
-            )
-        except Exception as e:
-            e.args += (str(self.fgraph),)
-            raise
-        finally:
-            release_lock()
+        with lock_ctx():
+            try:
+                _logger.debug(f"LOCATION {location}")
+                module = c_compiler.compile_str(
+                    module_name=mod.code_hash,
+                    src_code=src_code,
+                    location=location,
+                    include_dirs=self.header_dirs(),
+                    lib_dirs=self.lib_dirs(),
+                    libs=libs,
+                    preargs=preargs,
+                )
+            except Exception as e:
+                e.args += (str(self.fgraph),)
+                raise
         return module
 
     def get_dynamic_module(self):
@@ -1682,9 +1680,7 @@ class CLinker(Linker):
             self._mod = mod
         return self._mod
 
-    def cthunk_factory(
-        self, error_storage, in_storage, out_storage, storage_map=None, keep_lock=False
-    ):
+    def cthunk_factory(self, error_storage, in_storage, out_storage, storage_map=None):
         """
         Returns a thunk that points to an instance of a C struct that
         can carry on the computation of this linker's fgraph
@@ -1712,9 +1708,7 @@ class CLinker(Linker):
             # Set compute_map as None as clinker do not support lazy evaluation
             for node in self.node_order:
                 node.op.prepare_node(node, storage_map, None, "c")
-            module = get_module_cache().module_from_key(
-                key=key, lnk=self, keep_lock=keep_lock
-            )
+            module = get_module_cache().module_from_key(key=key, lnk=self)
 
         vars = self.inputs + self.outputs + self.orphans
         # List of indices that should be ignored when passing the arguments
@@ -1912,78 +1906,63 @@ class OpWiseCLinker(LocalLinker):
         self, profiler=None, input_storage=None, output_storage=None, storage_map=None
     ):
 
-        # The lock will be acquired when we compile the first
-        # C code. We will keep the lock until all the function
-        # compilation will be finished. This allow to don't
-        # require the lock when all c code are already compiled!
-        orig_n_lock = getattr(get_lock, "n_lock", 0)
-        try:
+        fgraph = self.fgraph
+        order = self.schedule(fgraph)
+        no_recycling = self.no_recycling
 
-            fgraph = self.fgraph
-            order = self.schedule(fgraph)
-            no_recycling = self.no_recycling
+        input_storage, output_storage, storage_map = map_storage(
+            fgraph, order, input_storage, output_storage, storage_map
+        )
+        if self.allow_gc:
+            computed, last_user = gc_helper(order)
+            post_thunk_old_storage = []
+        else:
+            post_thunk_old_storage = None
 
-            input_storage, output_storage, storage_map = map_storage(
-                fgraph, order, input_storage, output_storage, storage_map
-            )
+        compute_map = {}
+        for k in storage_map:
+            compute_map[k] = [k.owner is None]
+
+        thunks = []
+        for node in order:
+            # make_thunk will try by default C code, otherwise
+            # it fall back to python.
+            thunks += [node.op.make_thunk(node, storage_map, compute_map, no_recycling)]
+            thunks[-1].inputs = [storage_map[v] for v in node.inputs]
+            thunks[-1].outputs = [storage_map[v] for v in node.outputs]
+
+        for node in order:
             if self.allow_gc:
-                computed, last_user = gc_helper(order)
-                post_thunk_old_storage = []
-            else:
-                post_thunk_old_storage = None
+                post_thunk_old_storage.append(
+                    [
+                        storage_map[input]
+                        for input in node.inputs
+                        if (
+                            (input in computed)
+                            and (input not in fgraph.outputs)
+                            and node == last_user[input]
+                        )
+                    ]
+                )
 
-            compute_map = {}
-            for k in storage_map:
-                compute_map[k] = [k.owner is None]
+        if no_recycling is True:
+            no_recycling = list(storage_map.values())
+            no_recycling = difference(no_recycling, input_storage)
+        else:
+            no_recycling = [
+                storage_map[r] for r in no_recycling if r not in fgraph.inputs
+            ]
 
-            thunks = []
-            for node in order:
-                # make_thunk will try by default C code, otherwise
-                # it fall back to python.
-                thunks += [
-                    node.op.make_thunk(node, storage_map, compute_map, no_recycling)
-                ]
-                thunks[-1].inputs = [storage_map[v] for v in node.inputs]
-                thunks[-1].outputs = [storage_map[v] for v in node.outputs]
+        f = streamline(
+            fgraph,
+            thunks,
+            order,
+            post_thunk_old_storage,
+            no_recycling=no_recycling,
+            nice_errors=self.nice_errors,
+        )
 
-            for node in order:
-                if self.allow_gc:
-                    post_thunk_old_storage.append(
-                        [
-                            storage_map[input]
-                            for input in node.inputs
-                            if (
-                                (input in computed)
-                                and (input not in fgraph.outputs)
-                                and node == last_user[input]
-                            )
-                        ]
-                    )
-
-            if no_recycling is True:
-                no_recycling = list(storage_map.values())
-                no_recycling = utils.difference(no_recycling, input_storage)
-            else:
-                no_recycling = [
-                    storage_map[r] for r in no_recycling if r not in fgraph.inputs
-                ]
-
-            f = streamline(
-                fgraph,
-                thunks,
-                order,
-                post_thunk_old_storage,
-                no_recycling=no_recycling,
-                nice_errors=self.nice_errors,
-            )
-
-            f.allow_gc = self.allow_gc
-
-        finally:
-            # Release lock on compilation directory.
-            if getattr(get_lock, "n_lock", 0) > orig_n_lock:
-                release_lock()
-                assert get_lock.n_lock == orig_n_lock
+        f.allow_gc = self.allow_gc
 
         return (
             f,
@@ -2114,36 +2093,5 @@ class DualLinker(Linker):
         return f, i1, o1
 
 
-class HideC:
-    def __hide(*args):
-        raise utils.MethodNotDefined()
-
-    c_code = __hide
-    c_code_cleanup = __hide
-
-    c_headers = __hide
-    c_header_dirs = __hide
-    c_libraries = __hide
-    c_lib_dirs = __hide
-
-    c_support_code = __hide
-    c_support_code_apply = __hide
-
-    c_compile_args = __hide
-    c_no_compile_args = __hide
-    c_init_code = __hide
-    c_init_code_apply = __hide
-
-    c_init_code_struct = __hide
-    c_support_code_struct = __hide
-    c_cleanup_code_struct = __hide
-
-    def c_code_cache_version(self):
-        return ()
-
-    def c_code_cache_version_apply(self, node):
-        return self.c_code_cache_version()
-
-
 if config.cmodule__preload_cache:
     get_module_cache()
