@@ -1,7 +1,5 @@
 from collections.abc import Sequence
-from functools import reduce
-from functools import singledispatch as dispatch
-from functools import update_wrapper
+from functools import reduce, singledispatch, update_wrapper
 from warnings import warn
 
 import jax
@@ -17,6 +15,7 @@ from theano.compile.ops import (
     SpecifyShape,
     ViewOp,
 )
+from theano.configdefaults import config
 from theano.gof import FunctionGraph
 from theano.ifelse import IfElse
 from theano.scalar.basic import Cast, Clip, Composite, Identity, ScalarOp, Second
@@ -74,7 +73,7 @@ from theano.tensor.subtensor import (  # This is essentially `np.take`; Boolean
 from theano.tensor.type_other import MakeSlice
 
 
-if theano.config.floatX == "float64":
+if config.floatX == "float64":
     jax.config.update("jax_enable_x64", True)
 else:
     jax.config.update("jax_enable_x64", False)
@@ -192,7 +191,7 @@ def compose_jax_funcs(out_node, fgraph_inputs, memo=None):
     return jax_funcs
 
 
-@dispatch
+@singledispatch
 def jax_funcify(op):
     """Create a JAX "perform" function for a Theano `Variable` and its `Op`."""
     raise NotImplementedError(f"No JAX conversion for the given `Op`: {op}")
