@@ -15,8 +15,9 @@ from io import StringIO
 import numpy as np
 
 import theano
-from theano import config, gof
+from theano import gof
 from theano.compile import Function, SharedVariable, debugmode
+from theano.configdefaults import config
 from theano.gof import Apply, Op
 
 
@@ -819,7 +820,7 @@ def pydotprint(
             fct = fct.outputs
         assert isinstance(fct, (list, tuple))
         assert all(isinstance(v, gof.Variable) for v in fct)
-        fct = gof.FunctionGraph(inputs=gof.graph.inputs(fct), outputs=fct)
+        fct = gof.FunctionGraph(inputs=list(gof.graph.inputs(fct)), outputs=fct)
         profile = None
         outputs = fct.outputs
         topo = fct.toposort()
