@@ -3,6 +3,9 @@ import scipy
 
 import theano
 from theano import gof, scalar, tensor
+from theano.configdefaults import config
+from theano.gof.op import COp
+from theano.misc.safe_asarray import _asarray
 from theano.sparse import basic as sparse
 from theano.sparse.basic import (
     CSC,
@@ -75,7 +78,7 @@ theano.compile.optdb.register(
 )
 
 
-class AddSD_ccode(gof.op.Op):
+class AddSD_ccode(COp):
     """
     Add a sparse and a dense matrix.
 
@@ -100,7 +103,7 @@ class AddSD_ccode(gof.op.Op):
     __props__ = ("format", "inplace")
 
     def __init__(self, format, inplace=False, *args, **kwargs):
-        gof.Op.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
         # Should we do inplace addition or not ?
         self.inplace = inplace
         self.format = format
@@ -194,7 +197,7 @@ def local_inplace_addsd_ccode(fgraph, node):
     Optimization to insert inplace versions of AddSD.
 
     """
-    if isinstance(node.op, sparse.AddSD) and theano.config.cxx:
+    if isinstance(node.op, sparse.AddSD) and config.cxx:
         out_dtype = scalar.upcast(*node.inputs)
         if out_dtype != node.inputs[1].dtype:
             return
@@ -232,7 +235,7 @@ def local_addsd_ccode(fgraph, node):
     Convert AddSD to faster AddSD_ccode.
 
     """
-    if isinstance(node.op, sparse.AddSD) and theano.config.cxx:
+    if isinstance(node.op, sparse.AddSD) and config.cxx:
         new_node = AddSD_ccode(format=node.inputs[0].type.format)(*node.inputs)
         return [new_node]
     return False
@@ -247,7 +250,7 @@ theano.compile.optdb.register(
 )
 
 
-class StructuredDotCSC(gof.Op):
+class StructuredDotCSC(COp):
     """
     Structured Dot CSC is like dot, except that only the gradient wrt non-zero
     elements of the sparse matrix `a` are calculated and propagated.
@@ -291,7 +294,7 @@ class StructuredDotCSC(gof.Op):
             (a_val, a_ind, a_ptr), (a_nrows, b.shape[0]), copy=False
         )
         # out[0] = a.dot(b)
-        out[0] = theano._asarray(a * b, dtype=node.outputs[0].type.dtype)
+        out[0] = _asarray(a * b, dtype=node.outputs[0].type.dtype)
         assert _is_dense(out[0])  # scipy 0.7 automatically converts to dense
 
     def c_code(self, node, name, inputs, outputs, sub):
@@ -451,7 +454,7 @@ class StructuredDotCSC(gof.Op):
 sd_csc = StructuredDotCSC()
 
 
-class StructuredDotCSR(gof.Op):
+class StructuredDotCSR(COp):
     """
     Structured Dot CSR is like dot, except that only the
     gradient wrt non-zero elements of the sparse matrix
@@ -660,7 +663,7 @@ def local_structured_dot(fgraph, node):
 # register_specialize(local_structured_dot)
 
 
-class UsmmCscDense(gof.Op):
+class UsmmCscDense(COp):
     """
     Performs the expression is `alpha` * `x` `y` + `z`.
 
@@ -937,7 +940,7 @@ local_usmm = gof.opt.PatternSub(
             {
                 "pattern": "alpha",
                 "constraint": lambda expr: (
-                    np.all(expr.type.broadcastable) and theano.config.blas__ldflags
+                    np.all(expr.type.broadcastable) and config.blas__ldflags
                 ),
             },
             (sparse._dot, "x", "y"),
@@ -992,7 +995,7 @@ def local_usmm_csx(fgraph, node):
 register_specialize(local_usmm_csx, "cxx_only")
 
 
-class CSMGradC(gof.Op):
+class CSMGradC(COp):
 
     __props__ = ()
 
@@ -1135,7 +1138,7 @@ def local_csm_grad_c(fgraph, node):
 # register_specialize(local_csm_grad_c, 'cxx_only')
 
 
-class MulSDCSC(gof.Op):
+class MulSDCSC(COp):
     """
     Multiplication of sparse matrix by a broadcasted dense vector
     element wise.
@@ -1272,7 +1275,7 @@ class MulSDCSC(gof.Op):
 mul_s_d_csc = MulSDCSC()
 
 
-class MulSDCSR(gof.Op):
+class MulSDCSR(COp):
     """
     Multiplication of sparse matrix by a broadcasted dense vector
     element wise.
@@ -1460,7 +1463,7 @@ def local_mul_s_d(fgraph, node):
 register_specialize(local_mul_s_d, "cxx_only")
 
 
-class MulSVCSR(gof.Op):
+class MulSVCSR(COp):
     """
     Multiplication of sparse matrix by a broadcasted dense vector
     element wise.
@@ -1624,7 +1627,7 @@ def local_mul_s_v(fgraph, node):
 register_specialize(local_mul_s_v, "cxx_only")
 
 
-class StructuredAddSVCSR(gof.Op):
+class StructuredAddSVCSR(COp):
     """
     Structured addition of a sparse matrix and a dense vector.
     The elements of the vector are are only added to the corresponding
@@ -1803,7 +1806,7 @@ def local_structured_add_s_v(fgraph, node):
 register_specialize(local_structured_add_s_v, "cxx_only")
 
 
-class SamplingDotCSR(gof.Op):
+class SamplingDotCSR(COp):
     """
     Operand optimized for calculating the dot product dot(`x`, `y`.T) = `z`
     when you only want to calculate a subset of `z`.
@@ -2057,7 +2060,7 @@ sampling_dot_csr = SamplingDotCSR()
 # register a specialization to replace SamplingDot -> SamplingDotCsr
 @gof.local_optimizer([sparse.sampling_dot])
 def local_sampling_dot_csr(fgraph, node):
-    if not theano.config.blas__ldflags:
+    if not config.blas__ldflags:
         # The C implementation of SamplingDotCsr relies on BLAS routines
         return
     if node.op == sparse.sampling_dot:
