@@ -142,29 +142,32 @@ except ImportError:
 from functools import reduce
 
 import theano.scalar
-from theano import config
 from theano.compile.mode import optdb
+from theano.configdefaults import config
 from theano.gof import (
-    Apply,
-    EquilibriumOptimizer,
-    GlobalOptimizer,
     InconsistencyError,
-    Op,
     ReplacementDidNotRemoveError,
     SequenceDB,
-    local_optimizer,
     view_roots,
 )
-from theano.gof.opt import inherit_stack_trace
+from theano.gof.graph import Apply
+from theano.gof.op import COp, Op
+from theano.gof.opt import (
+    EquilibriumOptimizer,
+    GlobalOptimizer,
+    inherit_stack_trace,
+    local_optimizer,
+)
 from theano.gof.params_type import ParamsType
 from theano.gof.toolbox import ReplaceValidate
-from theano.gof.utils import MethodNotDefined, TestValueError, memoize
+from theano.gof.utils import MethodNotDefined, TestValueError
 from theano.printing import FunctionPrinter, debugprint, pprint
 from theano.scalar import bool as bool_t
 from theano.tensor import basic as tt
 from theano.tensor.blas_headers import blas_header_text, blas_header_version
 from theano.tensor.opt import in2out, local_dimshuffle_lift
 from theano.tensor.type import values_eq_approx_remove_inf_nan
+from theano.utils import memoize
 
 
 _logger = logging.getLogger("theano.tensor.blas")
@@ -189,7 +192,7 @@ try:
 except ImportError as e:
     have_fblas = False
     # This is used in Gemv and ScipyGer. We use CGemv and CGer
-    # when theano.config.blas__ldflags is defined. So we don't need a
+    # when config.blas__ldflags is defined. So we don't need a
     # warning in that case.
     if not config.blas__ldflags:
         _logger.warning(
@@ -404,7 +407,7 @@ def ldflags(libs=True, flags=False, libs_dir=False, include_dir=False):
         Extracted flags.
 
     """
-    ldflags_str = theano.config.blas__ldflags
+    ldflags_str = config.blas__ldflags
     return _ldflags(
         ldflags_str=ldflags_str,
         libs=libs,
@@ -424,7 +427,7 @@ def _ldflags(ldflags_str, libs, flags, libs_dir, include_dir):
     ----------
     ldflags_str : string
         The string to process. Typically, this will be the content of
-        `theano.config.blas__ldflags`.
+        `config.blas__ldflags`.
     libs : bool
         Extract flags starting with "-l".
     flags: bool
@@ -496,7 +499,7 @@ def _ldflags(ldflags_str, libs, flags, libs_dir, include_dir):
     return rval
 
 
-class GemmRelated(Op):
+class GemmRelated(COp):
     """Base class for Gemm and Dot22.
 
     This class provides a kind of templated gemm Op.
@@ -2049,7 +2052,7 @@ blas_optdb.register(
 )
 
 
-class BatchedDot(Op):
+class BatchedDot(COp):
     """
     Computes the batched dot product of two variables:
 
