@@ -1,6 +1,7 @@
 # import theano.tensor.basic as tt
 
-from theano import config
+from theano.configdefaults import config
+from theano.gof.op import COp
 from theano.gof.params_type import ParamsType
 from theano.scalar import bool as bool_t
 
@@ -23,7 +24,7 @@ from theano.tensor.blas import (
 from theano.tensor.opt import in2out
 
 
-class BaseBLAS:
+class BaseBLAS(COp):
     def c_libraries(self):
         return ldflags()
 
