@@ -3,14 +3,19 @@ from copy import copy
 import numpy as np
 
 import theano
-from theano import config, gof, scalar
-from theano.gof import Apply, COp, Op, OpenMPOp, ParamsType
+from theano import scalar
+from theano.configdefaults import config
+from theano.gof import ParamsType
+from theano.gof.graph import Apply
 from theano.gof.null_type import NullType
+from theano.gof.op import COp, ExternalCOp, OpenMPOp
 from theano.gradient import DisconnectedType
 from theano.misc.frozendict import frozendict
-from theano.printing import pprint
+from theano.misc.safe_asarray import _asarray
+from theano.printing import FunctionPrinter, pprint
 from theano.scalar import get_scalar_type
 from theano.tensor import elemwise_cgen as cgen
+from theano.utils import uniq
 
 
 _numpy_ver = [int(n) for n in np.__version__.split(".")[:2]]
@@ -46,12 +51,7 @@ def TensorConstant(*inputs, **kwargs):
     )
 
 
-##################
-#   DimShuffle   #
-##################
-
-
-class DimShuffle(COp):
+class DimShuffle(ExternalCOp):
     """
     Allows to reorder the dimensions of a tensor or insert or remove
     broadcastable dimensions.
@@ -155,7 +155,7 @@ class DimShuffle(COp):
         return self.shuffle + self.drop
 
     def __init__(self, input_broadcastable, new_order, inplace=True):
-        COp.__init__(self, [self.c_func_file], self.c_func_name)
+        super().__init__([self.c_func_file], self.c_func_name)
         self.input_broadcastable = tuple(input_broadcastable)
         self.new_order = tuple(new_order)
         if inplace is True:
@@ -217,8 +217,8 @@ class DimShuffle(COp):
         self.__dict__.update(state)
         if not hasattr(self, "func_files"):
             # Perhaps we are loading an old `Op` version of DimShuffle.
-            # Let's just build the COp.
-            COp.__init__(self, [self.c_func_file], self.c_func_name)
+            # Let's just build the ExternalCOp.
+            super().__init__([self.c_func_file], self.c_func_name)
 
     def make_node(self, _input):
         input = as_tensor_variable(_input)
@@ -341,11 +341,6 @@ class DimShufflePrinter:
 pprint.assign(DimShuffle, DimShufflePrinter())
 
 
-################
-#   Elemwise   #
-################
-
-
 class Elemwise(OpenMPOp):
     """
     Generalizes a scalar op to tensors.
@@ -905,12 +900,12 @@ second dimension
         _inames = inames
         _onames = onames
 
-        inames = gof.utils.uniq(inames)
-        inputs = gof.utils.uniq(node.inputs)
+        inames = uniq(inames)
+        inputs = uniq(node.inputs)
         # assert that inames and inputs order stay consistent.
         # This is to protect again futur change of uniq.
         assert len(inames) == len(inputs)
-        ii, iii = list(zip(*gof.utils.uniq(list(zip(_inames, node.inputs)))))
+        ii, iii = list(zip(*uniq(list(zip(_inames, node.inputs)))))
         assert all([x == y for x, y in zip(ii, inames)])
         assert all([x == y for x, y in zip(iii, inputs)])
 
@@ -1278,12 +1273,7 @@ second dimension
         return node.outputs[0].ndim == 0 and len(node.inputs) < 32
 
 
-################
-#   CAReduce   #
-################
-
-
-class CAReduce(Op):
+class CAReduce(COp):
     """
     CAReduce = Commutative Associative Reduce
     Reduces a scalar operation along the specified axis(es).
@@ -1358,9 +1348,9 @@ class CAReduce(Op):
             self.ufunc = np.add
         elif isinstance(scalar_op, theano.scalar.basic.Mul):
             self.ufunc = np.multiply
-        elif isinstance(scalar_op, theano.scalar.basic.Maximum):
+        elif isinstance(scalar_op, theano.scalar.basic.ScalarMaximum):
             self.ufunc = np.maximum
-        elif isinstance(scalar_op, theano.scalar.basic.Minimum):
+        elif isinstance(scalar_op, theano.scalar.basic.ScalarMinimum):
             self.ufunc = np.minimum
         elif isinstance(scalar_op, theano.scalar.basic.AND) and _numpy_ver >= [1, 12]:
             # numpy.bitwise_and.identity was incorrect for versions before
@@ -1473,7 +1463,7 @@ class CAReduce(Op):
                 # perhaps numpy is clever for reductions of size 1?
                 # We don't want this.
                 variable = variable.copy()
-            output[0] = theano._asarray(variable, dtype=node.outputs[0].type.dtype)
+            output[0] = _asarray(variable, dtype=node.outputs[0].type.dtype)
         else:
             # Force a copy
             output[0] = np.array(variable, copy=True, dtype=node.outputs[0].type.dtype)
@@ -1580,8 +1570,8 @@ class CAReduce(Op):
 
         if hasattr(self.scalar_op, "identity"):
             identity = self.scalar_op.identity
-        elif self.scalar_op in [scalar.maximum, scalar.minimum]:
-            if self.scalar_op == scalar.maximum:
+        elif self.scalar_op in [scalar.scalar_maximum, scalar.scalar_minimum]:
+            if self.scalar_op == scalar.scalar_maximum:
                 scal_name = "maximum"
                 if input.type.dtype in ["float32", "float64"]:
                     identity = "-__builtin_inf()"
@@ -1590,7 +1580,7 @@ class CAReduce(Op):
                     identity = "0"
                 else:
                     identity = "NPY_MIN_" + str(input.type.dtype).upper()
-            if self.scalar_op == scalar.minimum:
+            if self.scalar_op == scalar.scalar_minimum:
                 scal_name = "minimum"
                 if input.type.dtype in ["float32", "float64"]:
                     identity = "__builtin_inf()"
@@ -2250,3 +2240,55 @@ class ProdWithoutZeros(CAReduceDtype):
             "`product(a, no_zeros_in_input=True)`.",
         )
         return [a_grad]
+
+
+def scalar_elemwise(*symbol, nfunc=None, nin=None, nout=None, symbolname=None):
+    """Replace a symbol definition with an `Elemwise`-wrapped version of the corresponding scalar `Op`.
+
+    If it is not ``None``, the `nfunc` argument should be a string such that
+    ``getattr(numpy, nfunc)`` implements a vectorized version of the `Elemwise`
+    operation.  `nin` is the number of inputs expected by that function, and nout
+    is the number of **destination** inputs it takes.  That is, the function
+    should take nin + nout inputs. `nout == 0` means that the numpy function does
+    not take a NumPy array argument to put its result in.
+
+    """
+
+    def construct(symbol):
+        nonlocal symbolname
+
+        symbolname = symbolname or symbol.__name__
+
+        if symbolname.endswith("_inplace"):
+            elemwise_name = f"Elemwise{{{symbolname},inplace}}"
+            scalar_op = getattr(scalar, symbolname[: -len("_inplace")])
+            inplace_scalar_op = scalar_op.__class__(scalar.transfer_type(0))
+            rval = Elemwise(
+                inplace_scalar_op,
+                {0: 0},
+                name=elemwise_name,
+                nfunc_spec=(nfunc and (nfunc, nin, nout)),
+            )
+        else:
+            elemwise_name = f"Elemwise{{{symbolname},no_inplace}}"
+            scalar_op = getattr(scalar, symbolname)
+            rval = Elemwise(
+                scalar_op, name=elemwise_name, nfunc_spec=(nfunc and (nfunc, nin, nout))
+            )
+
+        if getattr(symbol, "__doc__"):
+            rval.__doc__ = symbol.__doc__ + "\n" + rval.__doc__
+
+        # for the meaning of this see the ./epydoc script
+        # it makes epydoc display rval as if it were a function, not an object
+        rval.__epydoc_asRoutine = symbol
+        rval.__module__ = symbol.__module__
+
+        pprint.assign(rval, FunctionPrinter(symbolname.replace("_inplace", "=")))
+
+        return rval
+
+    if symbol:
+        return construct(symbol[0])
+    else:
+        return construct
