@@ -3,20 +3,23 @@ from collections.abc import Collection
 import numpy as np
 
 import theano
-from theano.gof import Apply, EnumList, Generic, Op, ParamsType
+from theano.gof import EnumList, Generic, ParamsType
+from theano.gof.graph import Apply
+from theano.gof.op import COp, Op
 from theano.gradient import (
     DisconnectedType,
     _float_zeros_like,
     disconnected_type,
     grad_undefined,
 )
+from theano.misc.safe_asarray import _asarray
 from theano.scalar import int32 as int_t
 from theano.scalar import upcast
 from theano.tensor import basic, nlinalg
 from theano.utils import LOCAL_BITWIDTH, PYTHON_INT_BITWIDTH
 
 
-class CpuContiguous(Op):
+class CpuContiguous(COp):
     """
     Check to see if the input is c-contiguous,
     if it is, do nothing, else return a contiguous array.
@@ -77,7 +80,7 @@ class CpuContiguous(Op):
 cpu_contiguous = CpuContiguous()
 
 
-class SearchsortedOp(Op):
+class SearchsortedOp(COp):
     """Wrapper of numpy.searchsorted.
 
     For full documentation, see :func:`searchsorted`.
@@ -256,7 +259,7 @@ def searchsorted(x, v, side="left", sorter=None):
     return SearchsortedOp(side=side)(x, v, sorter)
 
 
-class CumOp(Op):
+class CumOp(COp):
     # See function cumsum/cumprod for docstring
 
     __props__ = ("axis", "mode")
@@ -1314,7 +1317,7 @@ class UnravelIndex(Op):
         res = np.unravel_index(indices, dims, order=self.order)
         assert len(res) == len(out)
         for i in range(len(out)):
-            ret = theano._asarray(res[i], node.outputs[0].dtype)
+            ret = _asarray(res[i], node.outputs[0].dtype)
             if ret.base is not None:
                 # NumPy will return a view when it can.
                 # But we don't want that.
@@ -1393,7 +1396,7 @@ class RavelMultiIndex(Op):
     def perform(self, node, inp, out):
         multi_index, dims = inp[:-1], inp[-1]
         res = np.ravel_multi_index(multi_index, dims, mode=self.mode, order=self.order)
-        out[0][0] = theano._asarray(res, node.outputs[0].dtype)
+        out[0][0] = _asarray(res, node.outputs[0].dtype)
 
 
 def ravel_multi_index(multi_index, dims, mode="raise", order="C"):
