@@ -2,8 +2,9 @@ import logging
 import os
 
 import theano
-from theano import gof
+from theano.configdefaults import config
 from theano.gof.graph import Apply
+from theano.gof.op import OpenMPOp
 from theano.gof.params_type import ParamsType
 from theano.gof.type import EnumList
 from theano.scalar import int8, int64
@@ -17,7 +18,7 @@ from theano.tensor.type import TensorType
 _logger = logging.getLogger(__name__)
 
 
-class BaseCorrMM(gof.OpenMPOp):
+class BaseCorrMM(OpenMPOp):
     """
     Base class for `CorrMM`, `CorrMM_gradWeights` and
     `CorrMM_gradInputs`. Cannot be used directly.
@@ -125,13 +126,13 @@ class BaseCorrMM(gof.OpenMPOp):
         self.filter_dilation = tuple(filter_dilation)
         self.unshared = unshared
 
-        if not theano.config.blas__ldflags:
+        if not config.blas__ldflags:
             # Theano will use a NumPy C implementation of [sd]gemm_ instead.
             self.blas_type = ""
         else:
-            if "openblas" in theano.config.blas__ldflags:
+            if "openblas" in config.blas__ldflags:
                 self.blas_type = "openblas"
-            elif "mkl" in theano.config.blas__ldflags:
+            elif "mkl" in config.blas__ldflags:
                 self.blas_type = "mkl"
             else:
                 self.blas_type = ""
