@@ -2,8 +2,9 @@ import logging
 import os
 
 import theano
-from theano import gof
+from theano.configdefaults import config
 from theano.gof.graph import Apply
+from theano.gof.op import OpenMPOp
 from theano.gof.params_type import ParamsType
 from theano.gof.type import EnumList
 from theano.scalar import int64
@@ -17,7 +18,7 @@ from theano.tensor.type import TensorType
 _logger = logging.getLogger(__name__)
 
 
-class BaseCorr3dMM(gof.OpenMPOp):
+class BaseCorr3dMM(OpenMPOp):
     """
     Base class for `Corr3dMM`, `Corr3dMM_gradWeights` and
     `Corr3dMM_gradInputs`. Cannot be used directly.
@@ -111,13 +112,13 @@ class BaseCorr3dMM(gof.OpenMPOp):
             raise ValueError("Number of groups should be greater than 0")
         self.num_groups = num_groups
 
-        if not theano.config.blas__ldflags:
+        if not config.blas__ldflags:
             # Theano will use a NumPy C implementation of [sd]gemm_ instead.
             self.blas_type = ""
         else:
-            if "openblas" in theano.config.blas__ldflags:
+            if "openblas" in config.blas__ldflags:
                 self.blas_type = "openblas"
-            elif "mkl" in theano.config.blas__ldflags:
+            elif "mkl" in config.blas__ldflags:
                 self.blas_type = "mkl"
             else:
                 self.blas_type = ""
