@@ -21,8 +21,9 @@ import numpy as np
 import theano
 from theano import scalar
 from theano.compile import optdb
+from theano.configdefaults import config
 from theano.gof.graph import Apply
-from theano.gof.op import Op
+from theano.gof.op import COp, Op
 from theano.gof.opt import copy_stack_trace, local_optimizer, optimizer
 from theano.gradient import DisconnectedType, grad_not_implemented
 from theano.scalar import UnaryScalarOp
@@ -43,7 +44,7 @@ from theano.tensor.subtensor import AdvancedSubtensor
 from theano.tensor.type import values_eq_approx_remove_inf, values_eq_approx_remove_nan
 
 
-class SoftmaxWithBias(Op):
+class SoftmaxWithBias(COp):
     """
     An L{Op} for the output of neural-net multiclass classifiers.
 
@@ -299,7 +300,7 @@ class SoftmaxWithBias(Op):
 softmax_with_bias = SoftmaxWithBias()
 
 
-class SoftmaxGrad(Op):
+class SoftmaxGrad(COp):
     """
     Gradient wrt x of the Softmax Op.
 
@@ -420,7 +421,7 @@ class SoftmaxGrad(Op):
 softmax_grad = SoftmaxGrad()
 
 
-class Softmax(Op):
+class Softmax(COp):
     r"""
     Softmax activation function
     :math:`\\varphi(\\mathbf{x})_j =
@@ -621,7 +622,7 @@ class Softmax(Op):
 softmax_op = Softmax()
 
 
-class LogSoftmax(Op):
+class LogSoftmax(COp):
     r"""
     LogSoftmax activation function
     :math:`\\varphi(\\mathbf{x})_j =
@@ -960,7 +961,7 @@ def softmax_simplifier(numerators, denominators):
 opt.local_mul_canonizer.add_simplifier(softmax_simplifier, "softmax_simplifier")
 
 
-class CrossentropySoftmaxArgmax1HotWithBias(Op):
+class CrossentropySoftmaxArgmax1HotWithBias(COp):
     """
     A special compound L{Op} for the output of neural-net classifiers.
 
@@ -998,7 +999,7 @@ class CrossentropySoftmaxArgmax1HotWithBias(Op):
     __props__ = ()
 
     def __init__(self, **kwargs):
-        Op.__init__(self, **kwargs)
+        super().__init__(**kwargs)
 
     def make_node(self, x, b, y_idx):
         x = tt.as_tensor_variable(x)
@@ -1219,7 +1220,7 @@ class CrossentropySoftmaxArgmax1HotWithBias(Op):
         return code_template % dict(locals(), **sub)
 
 
-class CrossentropySoftmax1HotWithBiasDx(Op):
+class CrossentropySoftmax1HotWithBiasDx(COp):
     """
     Gradient wrt x of the CrossentropySoftmaxArgmax1HotWithBias Op.
 
@@ -1661,7 +1662,7 @@ def local_argmax_pushdown(fgraph, node):
             softmax_with_bias,
         )
     ):
-        if theano.config.warn__argmax_pushdown_bug:
+        if config.warn__argmax_pushdown_bug:
             logging.getLogger("theano.tensor.nnet.nnet").warn(
                 "There was a bug in Theano fixed on May 27th, 2010 in this case."
                 " I.E. when we take the max of a softplus, softmax, exp, "
