@@ -12,7 +12,8 @@ import warnings
 import numpy as np
 
 import theano
-from theano import config, gof, printing, scalar
+from theano import gof, printing, scalar
+from theano.configdefaults import config
 from theano.gof.opt import copy_stack_trace
 from theano.printing import pprint
 from theano.tensor import basic as tensor
@@ -73,9 +74,9 @@ class ScalarSigmoid(scalar.UnaryScalarOp):
         # import numpy, theano
         # dt='float32'  # or float64
         # for i in range(750):
-        #     print i, repr(theano._asarray(1.0, dtype=dt) /
-        #                   (theano._asarray(1.0, dtype=dt) +
-        #                    numpy.exp(-theano._asarray([i,-i], dtype=dt))))
+        #     print i, repr(_asarray(1.0, dtype=dt) /
+        #                   (_asarray(1.0, dtype=dt) +
+        #                    numpy.exp(-_asarray([i,-i], dtype=dt))))
 
         # float16 limits: -11.0, 7.0f
         # We use the float32 limits for float16 for now as the
@@ -101,10 +102,7 @@ class ScalarSigmoid(scalar.UnaryScalarOp):
     def c_code_contiguous_disabled(self, node, name, inp, out, sub):
         (x,) = inp
         (z,) = out
-        if (
-            not theano.config.lib__amblibm
-            or node.inputs[0].dtype != node.outputs[0].dtype
-        ):
+        if not config.lib__amblibm or node.inputs[0].dtype != node.outputs[0].dtype:
             raise theano.gof.utils.MethodNotDefined()
         dtype = node.inputs[0].dtype
         if dtype == "float32" and self.amd_float32 is not None:
@@ -381,7 +379,7 @@ class ScalarSoftplus(scalar.UnaryScalarOp):
         # These constants were obtained by looking at the output of
         # python commands like:
         #  for i in range(750):
-        #      print i, repr(numpy.log1p(numpy.exp(theano._asarray([i,-i], dtype=dt))))
+        #      print i, repr(numpy.log1p(numpy.exp(_asarray([i,-i], dtype=dt))))
         # the boundary checks prevent us from generating inf
 
         # float16 limits: -17.0, 6.0
