@@ -7,10 +7,15 @@ from textwrap import dedent
 import numpy as np
 
 import theano
-from theano import config, gof
+from theano import gof
 from theano import scalar as scal
-from theano.gof import Apply, MethodNotDefined, Op, ParamsType, Type, hashtype
+from theano.configdefaults import config
+from theano.gof import MethodNotDefined, ParamsType
+from theano.gof.graph import Apply
+from theano.gof.op import COp, Op
+from theano.gof.type import Type
 from theano.gradient import DisconnectedType
+from theano.misc.safe_asarray import _asarray
 from theano.printing import pprint
 from theano.tensor.basic import (
     NotScalarConstantError,
@@ -416,7 +421,7 @@ def indexed_result_shape(array_shape, indices, indices_are_shapes=False):
     return res_shape
 
 
-class Subtensor(Op):
+class Subtensor(COp):
     """Basic NumPy indexing operator."""
 
     check_input = False
@@ -1379,7 +1384,7 @@ def inc_subtensor(
         raise TypeError("x must be the result of a subtensor operation")
 
 
-class IncSubtensor(Op):
+class IncSubtensor(COp):
     """
     Increment a subtensor.
 
@@ -1417,25 +1422,11 @@ class IncSubtensor(Op):
         self.set_instead_of_inc = set_instead_of_inc
 
     def __hash__(self):
-        msg = []
-        for entry in self.idx_list:
-            if isinstance(entry, slice):
-                msg += [(entry.start, entry.stop, entry.step)]
-            else:
-                msg += [entry]
-
-        idx_list = tuple(msg)
-        # backport
-        # idx_list = tuple((entry.start, entry.stop, entry.step)
-        #                 if isinstance(entry, slice)
-        #                 else entry
-        #                 for entry in self.idx_list)
-        return (
-            hashtype(self)
-            ^ hash(idx_list)
-            ^ hash(self.inplace)
-            ^ hash(self.set_instead_of_inc)
+        idx_list = tuple(
+            (entry.start, entry.stop, entry.step) if isinstance(entry, slice) else entry
+            for entry in self.idx_list
         )
+        return hash((type(self), idx_list, self.inplace, self.set_instead_of_inc))
 
     def __str__(self):
         indices = []
@@ -1852,7 +1843,7 @@ def _sum_grad_over_bcasted_dims(x, gx):
     return gx
 
 
-class AdvancedSubtensor1(Op):
+class AdvancedSubtensor1(COp):
     """
     Implement x[ilist] where ilist is a vector of integers.
 
@@ -1897,7 +1888,7 @@ class AdvancedSubtensor1(Op):
         # if they don't, that should be an error (no array can have that
         # many elements on a 32-bit arch).
         if i.dtype != np.intp:
-            i_ = theano._asarray(i, dtype=np.intp)
+            i_ = _asarray(i, dtype=np.intp)
             if not np.can_cast(i.dtype, np.intp):
                 # Check if there was actually an incorrect conversion
                 if np.any(i != i_):
@@ -2056,7 +2047,7 @@ class AdvancedSubtensor1(Op):
 advanced_subtensor1 = AdvancedSubtensor1()
 
 
-class AdvancedIncSubtensor1(Op):
+class AdvancedIncSubtensor1(COp):
     """
     Increments a subtensor using advanced slicing (list of index).
 
