@@ -4,9 +4,11 @@ import warnings
 import numpy as np
 
 import theano
-from theano import config
 from theano import scalar as scal
-from theano.gof import Type, Variable, hashtype
+from theano.configdefaults import config
+from theano.gof.graph import Variable
+from theano.gof.type import Type
+from theano.misc.safe_asarray import _asarray
 
 
 _logger = logging.getLogger("theano.tensor.type")
@@ -101,7 +103,7 @@ class TensorType(Type):
             pass
         elif isinstance(data, np.ndarray) and (data.dtype == self.numpy_dtype):
             if data.dtype.num != self.numpy_dtype.num:
-                data = theano._asarray(data, dtype=self.dtype)
+                data = _asarray(data, dtype=self.dtype)
             # -- now fall through to ndim check
         elif strict:
             # If any of the two conditions above was not met,
@@ -115,7 +117,7 @@ class TensorType(Type):
         else:
             if allow_downcast:
                 # Convert to self.dtype, regardless of the type of data
-                data = theano._asarray(data, dtype=self.dtype)
+                data = _asarray(data, dtype=self.dtype)
                 # TODO: consider to pad shape with ones to make it consistent
                 # with self.broadcastable... like vector->row type thing
             else:
@@ -128,7 +130,7 @@ class TensorType(Type):
                         # scalar array, see
                         # http://projects.scipy.org/numpy/ticket/1611
                         # data = data.astype(self.dtype)
-                        data = theano._asarray(data, dtype=self.dtype)
+                        data = _asarray(data, dtype=self.dtype)
                     if up_dtype != self.dtype:
                         err_msg = (
                             f"{self} cannot store a value of dtype {data.dtype} without "
@@ -142,15 +144,15 @@ class TensorType(Type):
                 elif (
                     allow_downcast is None
                     and isinstance(data, (float, np.floating))
-                    and self.dtype == theano.config.floatX
+                    and self.dtype == config.floatX
                 ):
                     # Special case where we allow downcasting of Python float
                     # literals to floatX, even when floatX=='float32'
-                    data = theano._asarray(data, self.dtype)
+                    data = _asarray(data, self.dtype)
                 else:
                     # data has to be converted.
                     # Check that this conversion is lossless
-                    converted_data = theano._asarray(data, self.dtype)
+                    converted_data = _asarray(data, self.dtype)
                     # We use the `values_eq` static function from TensorType
                     # to handle NaN values.
                     if TensorType.values_eq(
@@ -342,8 +344,7 @@ class TensorType(Type):
         return values_eq_approx(a, b, allow_remove_inf, allow_remove_nan, rtol, atol)
 
     def __hash__(self):
-        """Hash equal for same kinds of TensorType"""
-        return hashtype(self) ^ hash(self.dtype) ^ hash(self.broadcastable)
+        return hash((type(self), self.dtype, self.broadcastable))
 
     ndim = property(lambda self: len(self.broadcastable), doc="number of dimensions")
     """
