@@ -1,9 +1,10 @@
 import numpy as np
 
-import theano
 import theano.tensor as tt
 from theano.compile.debugmode import _lessbroken_deepcopy
-from theano.gof import Apply, Constant, Op, Variable
+from theano.configdefaults import config
+from theano.gof.graph import Apply, Constant, Variable
+from theano.gof.op import COp, Op
 from theano.tensor.type_other import SliceType
 from theano.typed_list.type import TypedListType
 
@@ -62,7 +63,7 @@ class TypedListConstant(_typed_list_py_operators, Constant):
 TypedListType.Constant = TypedListConstant
 
 
-class GetItem(Op):
+class GetItem(COp):
     # See doc in instance of this Op or function after this class definition.
     view_map = {0: [0]}
     __props__ = ()
@@ -127,7 +128,7 @@ index
 """
 
 
-class Append(Op):
+class Append(COp):
     # See doc in instance of this Op after the class definition.
     __props__ = ("inplace",)
 
@@ -210,7 +211,7 @@ y
 """
 
 
-class Extend(Op):
+class Extend(COp):
     # See doc in instance of this Op after the class definition.
     __props__ = ("inplace",)
 
@@ -299,7 +300,7 @@ toAppend
 """
 
 
-class Insert(Op):
+class Insert(COp):
     # See doc in instance of this Op after the class definition.
     __props__ = ("inplace",)
 
@@ -446,7 +447,7 @@ from a list. This implementation works in that case.
 """
 
 
-class Reverse(Op):
+class Reverse(COp):
     # See doc in instance of this Op after the class definition.
     __props__ = ("inplace",)
 
@@ -536,7 +537,7 @@ class Index(Op):
         (out,) = outputs
         for y in range(len(x)):
             if node.inputs[0].ttype.values_eq(x[y], elem):
-                out[0] = np.asarray(y, dtype=theano.config.floatX)
+                out[0] = np.asarray(y, dtype=config.floatX)
                 break
 
     def __str__(self):
@@ -567,7 +568,7 @@ class Count(Op):
         for y in range(len(x)):
             if node.inputs[0].ttype.values_eq(x[y], elem):
                 out[0] += 1
-        out[0] = np.asarray(out[0], dtype=theano.config.floatX)
+        out[0] = np.asarray(out[0], dtype=config.floatX)
 
     def __str__(self):
         return self.__class__.__name__
@@ -593,7 +594,7 @@ from a list. This implementation works in that case.
 """
 
 
-class Length(Op):
+class Length(COp):
     # See doc in instance of this Op after the class definition.
     __props__ = ()
 
@@ -645,12 +646,12 @@ class MakeList(Op):
         assert isinstance(a, (tuple, list))
         a2 = []
         for elem in a:
-            if not isinstance(elem, theano.gof.Variable):
+            if not isinstance(elem, Variable):
                 elem = tt.as_tensor_variable(elem)
             a2.append(elem)
         if not all(a2[0].type == elem.type for elem in a2):
             raise TypeError("MakeList need all input variable to be of the same type.")
-        tl = theano.typed_list.TypedListType(a2[0].type)()
+        tl = TypedListType(a2[0].type)()
 
         return Apply(self, a2, [tl])
 
