@@ -1,7 +1,8 @@
 """Utility functions that only depend on the standard library."""
 
-
+import hashlib
 import inspect
+import logging
 import os
 import struct
 import subprocess
@@ -10,7 +11,7 @@ import traceback
 import warnings
 from collections import OrderedDict
 from collections.abc import Callable
-from functools import wraps
+from functools import partial, wraps
 
 
 __all__ = [
@@ -24,6 +25,7 @@ __all__ = [
     "output_subprocess_Popen",
     "LOCAL_BITWIDTH",
     "PYTHON_INT_BITWIDTH",
+    "NoDuplicateOptWarningFilter",
 ]
 
 
@@ -284,3 +286,135 @@ def output_subprocess_Popen(command, **params):
     # the stdout/stderr pipe.
     out = p.communicate()
     return out + (p.returncode,)
+
+
+def hash_from_code(msg):
+    """Return the SHA256 hash of a string or bytes."""
+    # hashlib.sha256() requires an object that supports buffer interface,
+    # but Python 3 (unicode) strings don't.
+    if isinstance(msg, str):
+        msg = msg.encode()
+    # Python 3 does not like module names that start with
+    # a digit.
+    return "m" + hashlib.sha256(msg).hexdigest()
+
+
+def memoize(f):
+    """
+    Cache the return value for each tuple of arguments (which must be hashable).
+
+    """
+    cache = {}
+
+    def rval(*args, **kwargs):
+        kwtup = tuple(kwargs.items())
+        key = (args, kwtup)
+        if key not in cache:
+            val = f(*args, **kwargs)
+            cache[key] = val
+        else:
+            val = cache[key]
+        return val
+
+    return rval
+
+
+def uniq(seq):
+    """
+    Do not use set, this must always return the same value at the same index.
+    If we just exchange other values, but keep the same pattern of duplication,
+    we must keep the same order.
+
+    """
+    # TODO: consider building a set out of seq so that the if condition
+    # is constant time -JB
+    return [x for i, x in enumerate(seq) if seq.index(x) == i]
+
+
+def difference(seq1, seq2):
+    r"""
+    Returns all elements in seq1 which are not in seq2: i.e ``seq1\seq2``.
+
+    """
+    try:
+        # try to use O(const * len(seq1)) algo
+        if len(seq2) < 4:  # I'm guessing this threshold -JB
+            raise Exception("not worth it")
+        set2 = set(seq2)
+        return [x for x in seq1 if x not in set2]
+    except Exception:
+        # maybe a seq2 element is not hashable
+        # maybe seq2 is too short
+        # -> use O(len(seq1) * len(seq2)) algo
+        return [x for x in seq1 if x not in seq2]
+
+
+def to_return_values(values):
+    if len(values) == 1:
+        return values[0]
+    else:
+        return values
+
+
+def from_return_values(values):
+    if isinstance(values, (list, tuple)):
+        return values
+    else:
+        return [values]
+
+
+def flatten(a):
+    """
+    Recursively flatten tuple, list and set in a list.
+
+    """
+    if isinstance(a, (tuple, list, set)):
+        l = []
+        for item in a:
+            l.extend(flatten(item))
+        return l
+    else:
+        return [a]
+
+
+class NoDuplicateOptWarningFilter(logging.Filter):
+    """Filter to avoid duplicating optimization warnings."""
+
+    prev_msgs = set()
+
+    def filter(self, record):
+        msg = record.getMessage()
+        if msg.startswith("Optimization Warning: "):
+            if msg in self.prev_msgs:
+                return False
+            else:
+                self.prev_msgs.add(msg)
+                return True
+        return True
+
+
+def apply_across_args(*fns):
+    """Create new functions that distributes the wrapped functions across iterable arguments.
+
+    For example, a function, `fn`, that uses this decorator satisfies
+    `fn("hi") == [fn("h"), fn("i")]`.
+    """
+
+    def f2(f, *names):
+        if names and isinstance(names[0], int):
+            if names == 1:
+                return f()
+            else:
+                return [f() for i in range(names[0])]
+        if isinstance(names, tuple):
+            if len(names) == 1:
+                names = names[0]
+        if len(names) == 1:
+            return f(names)
+        else:
+            return [f(name) for name in names]
+
+    if len(fns) == 1:
+        return partial(f2, fns[0])
+    else:
+        return [partial(f2, f) for f in fns]
